//
//  HIDDevice.h
//  HIDController
//
//  Created by Joel Jordan on 11/28/07.
//  Copyright 2007 L510 Labs. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#include <CoreFoundation/CoreFoundation.h>
#include <IOKit/IOKitLib.h>
#include <IOKit/IOCFPlugIn.h>
#include <IOKit/IOMessage.h>
#include <IOKit/hid/IOHIDLib.h>
#include <IOKit/hid/IOHIDKeys.h>
#include <IOKit/hid/IOHIDUsageTables.h>
#include <IOKit/hidsystem/IOHIDLib.h>
#include <IOKit/hidsystem/IOHIDShared.h>
#include <IOKit/hidsystem/IOHIDParameter.h>

#import "HIDElement.h"

@interface HIDDevice : NSObject {
	// interface display vars
	NSString *transport;
	NSNumber *vendorID;
	NSNumber *productID;
	NSNumber *versionNumber;
	NSString *manufacturer;
	NSString *productName;
	NSString *serialNumber;
	NSArray  *usages;		// all possible device usage/usagePage combinations
	NSArray  *elements;		// this is a tree (array of arrays)

	BOOL elementActive; // set if at least one element has had activity in the last 0.2 s
	int activeElementCount;
	
	NSMutableDictionary *cookieDict;
	NSMutableArray *activeElements;	// list of all the elements that have seen activity recently
	// bookkeeping objects
	io_service_t			devObj;	// the IO registry object
	IOHIDDeviceInterface	**hidDev;	// the interface
	IOHIDQueueInterface		**queue;	// event queue
}

- (NSString *)transport;
- (NSNumber *)vendorID;
- (NSNumber *)productID;
- (NSNumber *)versionNumber;
- (NSString *)manufacturer;
- (NSString *)productName;
- (NSString *)serialNumber;
- (NSArray *)elements;
- (BOOL) elementActive;
- (void) setElementActive:(BOOL)newActive;
- (io_service_t) devObj;
- (void)removeActiveElement:(HIDElement *)element;
- (void)addActiveElement:(HIDElement *)element;
- (IOHIDQueueInterface **) queue;
- (NSDictionary *)cookieDict;
- (id)initWithDeviceObject:(io_service_t) deviceObject;

@end