//
//  HIDElement.m
//  HIDController
//
//  Created by Joel Jordan on 11/29/07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#include <CoreFoundation/CoreFoundation.h>
#include <IOKit/IOKitLib.h>
#include <IOKit/IOCFPlugIn.h>
#include <IOKit/IOMessage.h>
#include <IOKit/hid/IOHIDLib.h>
#include <IOKit/hid/IOHIDKeys.h>
#include <IOKit/hid/IOHIDUsageTables.h>
#include <IOKit/hidsystem/IOHIDLib.h>
#include <IOKit/hidsystem/IOHIDShared.h>
#include <IOKit/hidsystem/IOHIDParameter.h>

#import "HIDElement.h"
#include "HIDTables.h"

static NSString *createNameFromUsage(NSDictionary *properties) {
	NSNumber *usage;
	NSNumber *usagePage;
	NSString *usagePageStr;
	NSString *usageStr;
	
	NSString *name = nil;
	unsigned int usageInt;
	usage = (NSNumber *) [properties objectForKey:@kIOHIDElementUsageKey];
	usagePage = (NSNumber *) [properties objectForKey:@kIOHIDElementUsagePageKey];

	usagePageStr = [NSString stringWithFormat:@"%04X (unknown)", [usagePage intValue]];
	
	usageInt = [usage intValue];

	if ([usagePage intValue] < 0x91) {
		usagePageStr = [NSString stringWithCString:usagePageNames[[usagePage intValue]]];
		if ([usagePageStr isEqualToString:@"(Reserved)"]) {
			usagePageStr = [NSString stringWithFormat:@"%04X (Reserved)", [usagePage intValue]];
		}
	} else if ([usagePage intValue] >= 0xFF00) {
		usagePageStr = [NSString stringWithString:@"Vendor Defined"];
	}

	usageStr = [NSString stringWithFormat:@"[%@] %04X (unknown)", usagePageStr, usageInt];
		
	
	switch ([usagePage intValue]) {
		case 1:
			if (usageInt <= 0xB7) {
				usageStr = [NSString stringWithCString:usagePage01[usageInt].name];
			}
			break;
		case 2:
			if (usageInt < 0x26) {
				usageStr = [NSString stringWithCString:usagePage02_1[usageInt].name];
			} else if (usageInt > 0xB0 && usageInt < 0xD1) {
				usageStr = [NSString stringWithCString:usagePage02_2[usageInt-0xB0].name];
			}
			break;
		case 3:
			if (usageInt < 0x22) {
				usageStr = [NSString stringWithCString:usagePage03[usageInt].name];
			}
			break;
		case 4:
			if (usageInt < 0x64) {
				usageStr = [NSString stringWithCString:usagePage04[usageInt].name];
			}
			break;
		case 5:
			if (usageInt < 0x3A) {
				usageStr = [NSString stringWithCString:usagePage05[usageInt].name];
			}
			break;
		case 6:
			if (usageInt < 0x27) {
				usageStr = [NSString stringWithCString:usagePage06[usageInt].name];
			}
			break;
		case 7:
			if (usageInt < 0xE8) {
				usageStr = [NSString stringWithCString:usagePage07[usageInt].name];
			}
			break;
		case 8:
			if (usageInt < 0x4E) {
				usageStr = [NSString stringWithCString:usagePage07[usageInt].name];
			}
			break;
		case 9:
			usageStr = [NSString stringWithFormat:@"Button %d", usageInt];
			break;
		case 0x0A:
			usageStr = [NSString stringWithFormat:@"Instance %d", usageInt];
			break;
		case 0x0B:
			if (usageInt < 0xC0) {
				usageStr = [NSString stringWithCString:usagePage0B[usageInt].name];
			}
			break;
		case 0x0C:
			if (usageInt < 0x29D) {
				usageStr = [NSString stringWithCString:usagePage0C[usageInt].name];
			}
			break;
		case 0x0D:
			if (usageInt < 0x47) {
				usageStr = [NSString stringWithCString:usagePage0D[usageInt].name];
			}
			break;
		case 0x14:
			if (usageInt < 0x96) {
				usageStr = [NSString stringWithCString:usagePage14[usageInt].name];
			}
			break;
		case 0x40:
			if (usageInt < 0xA2) {
				usageStr = [NSString stringWithCString:usagePage40[usageInt].name];
			}
			break;
	}
	if ([usageStr isEqualToString:@"(Reserved)"]) {
		usageStr = [NSString stringWithFormat:@"[%@] %04X (Reserved)", usagePageStr, [usage intValue]];
	}
		
	name = [[NSString alloc] initWithString:usageStr];
		
	return name;
}

@implementation HIDElement
- (id)initFromDictionary:(NSDictionary *)elementDict {
	NSNumber *cookieObj;
	elements = nil;
	activeCount = 0;
	properties = elementDict;
	[properties retain];
	name = createNameFromUsage(properties);
	if ([properties objectForKey:@kIOHIDElementKey]) {
		NSMutableArray *newElements;
		NSEnumerator *elementEnum;
		NSDictionary *elementDict;
		newElements = [[NSMutableArray alloc] init];
		elementEnum = [[properties objectForKey:@kIOHIDElementKey] objectEnumerator];
		while (elementDict = [elementEnum nextObject]) {
			HIDElement *newElement;
			newElement = [[HIDElement alloc] initFromDictionary:elementDict];
			[newElements addObject:newElement];
			[newElement release];
		}
		elements = [newElements copy];
	}
	cookieObj = (NSNumber *) [properties objectForKey:@kIOHIDElementCookieKey];
	[self setCookie:(IOHIDElementCookie)[cookieObj longValue]];
		
	return self;
}

- (NSArray *)elements {
	return elements;
}

- (NSString *)name {
	return name;
}

- (BOOL)hasChildren {
	return (elements == nil);
}

- (NSDictionary *)properties {
	return properties;
}

- (void)dealloc {
	[properties release];
	[elements release];
	[super dealloc];
}

- (BOOL)active {
	return (activeCount == 0);
}

- (void)setActive:(BOOL)newActiveFlag {
	if (newActiveFlag) {
		activeCount++;
	} else {
		activeCount--;
	}
}

- (IOHIDElementCookie)cookie {
	return cookie;
}

- (void)setCookie:(IOHIDElementCookie)newCookie {
	cookie = newCookie;
}

@end
