/*
 *  HIDTables.h
 *  HIDController
 *
 *  Created by Joel Jordan on 11/30/07.
 *  Copyright 2007 L510 Labs. All rights reserved.
 *
 */

typedef enum usageType {
	None,
	LinearControl,
	OnOffControl,
	MomentaryControl,
	OneShotControl,
	RetriggerControl,
	Selector,
	StaticValue,
	StaticFlag,
	DynamicValue,
	DynamicFlag,
	NamedArray,
	ApplicationCollection,
	LogicalCollection,
	PhysicalCollection,
	UsageSwitch,
	UsageModifier,
	BufferedByte
} usageType;

typedef struct usageInfo {
	const char *name;
	usageType  type;  
} usageInfo;

static const char *usagePageNames[] = {
	"Undefined",												// 0x00
	"Generic Desktop Controls",									// 0x01
	"Simulation Controls",										// 0x02
	"VR Controls",												// 0x03
	"Sport Controls",											// 0x04
	"Game Controls",											// 0x05
	"Generic Device Controls",									// 0x06
	"Keyboard/Keypad",											// 0x07
	"LEDs",														// 0x08
	"Button",													// 0x09
	"Ordinal",													// 0x0A
	"Telephony",												// 0x0B
	"Consumer",													// 0x0C
	"Digitizer",												// 0x0D
	"(Reserved)",												// 0x0E
	"Physical Interfaace Device",								// 0x0F
	"Unicode",													// 0x10
	"(Reserved)",												// 0x11
	"(Reserved)",												// 0x12
	"(Reserved)",												// 0x13
	"Alphanumeric Display",										// 0x14
	"(Reserved)",												// 0x15
	"(Reserved)",												// 0x16
	"(Reserved)",												// 0x17
	"(Reserved)",												// 0x18
	"(Reserved)",												// 0x19
	"(Reserved)",												// 0x1A
	"(Reserved)",												// 0x1B
	"(Reserved)",												// 0x1C
	"(Reserved)",												// 0x1D
	"(Reserved)",												// 0x1E
	"(Reserved)",												// 0x1F
	"(Reserved)",												// 0x20
	"(Reserved)",												// 0x21
	"(Reserved)",												// 0x22
	"(Reserved)",												// 0x23
	"(Reserved)",												// 0x24
	"(Reserved)",												// 0x25
	"(Reserved)",												// 0x26
	"(Reserved)",												// 0x27
	"(Reserved)",												// 0x28
	"(Reserved)",												// 0x29
	"(Reserved)",												// 0x2A
	"(Reserved)",												// 0x2B
	"(Reserved)",												// 0x2C
	"(Reserved)",												// 0x2D
	"(Reserved)",												// 0x2E
	"(Reserved)",												// 0x2F
	"(Reserved)",												// 0x30
	"(Reserved)",												// 0x31
	"(Reserved)",												// 0x32
	"(Reserved)",												// 0x33
	"(Reserved)",												// 0x34
	"(Reserved)",												// 0x35
	"(Reserved)",												// 0x36
	"(Reserved)",												// 0x37
	"(Reserved)",												// 0x38
	"(Reserved)",												// 0x39
	"(Reserved)",												// 0x3A
	"(Reserved)",												// 0x3B
	"(Reserved)",												// 0x3C
	"(Reserved)",												// 0x3D
	"(Reserved)",												// 0x3E
	"(Reserved)",												// 0x3F
	"Medical Instruments",										// 0x40
	"(Reserved)",												// 0x41
	"(Reserved)",												// 0x42
	"(Reserved)",												// 0x43
	"(Reserved)",												// 0x44
	"(Reserved)",												// 0x45
	"(Reserved)",												// 0x46
	"(Reserved)",												// 0x47
	"(Reserved)",												// 0x48
	"(Reserved)",												// 0x49
	"(Reserved)",												// 0x4A
	"(Reserved)",												// 0x4B
	"(Reserved)",												// 0x4C
	"(Reserved)",												// 0x4D
	"(Reserved)",												// 0x4E
	"(Reserved)",												// 0x4F
	"(Reserved)",												// 0x50
	"(Reserved)",												// 0x51
	"(Reserved)",												// 0x52
	"(Reserved)",												// 0x53
	"(Reserved)",												// 0x54
	"(Reserved)",												// 0x55
	"(Reserved)",												// 0x56
	"(Reserved)",												// 0x57
	"(Reserved)",												// 0x58
	"(Reserved)",												// 0x59
	"(Reserved)",												// 0x5A
	"(Reserved)",												// 0x5B
	"(Reserved)",												// 0x5C
	"(Reserved)",												// 0x5D
	"(Reserved)",												// 0x5E
	"(Reserved)",												// 0x5F
	"(Reserved)",												// 0x60
	"(Reserved)",												// 0x61
	"(Reserved)",												// 0x62
	"(Reserved)",												// 0x63
	"(Reserved)",												// 0x64
	"(Reserved)",												// 0x65
	"(Reserved)",												// 0x66
	"(Reserved)",												// 0x67
	"(Reserved)",												// 0x68
	"(Reserved)",												// 0x69
	"(Reserved)",												// 0x6A
	"(Reserved)",												// 0x6B
	"(Reserved)",												// 0x6C
	"(Reserved)",												// 0x6D
	"(Reserved)",												// 0x6E
	"(Reserved)",												// 0x6F
	"(Reserved)",												// 0x70
	"(Reserved)",												// 0x71
	"(Reserved)",												// 0x72
	"(Reserved)",												// 0x73
	"(Reserved)",												// 0x74
	"(Reserved)",												// 0x75
	"(Reserved)",												// 0x76
	"(Reserved)",												// 0x77
	"(Reserved)",												// 0x78
	"(Reserved)",												// 0x79
	"(Reserved)",												// 0x7A
	"(Reserved)",												// 0x7B
	"(Reserved)",												// 0x7C
	"(Reserved)",												// 0x7D
	"(Reserved)",												// 0x7E
	"(Reserved)",												// 0x7F
	"Monitor Page 1",											// 0x80
	"Monitor Page 2",											// 0x81
	"Monitor Page 3",											// 0x82
	"Monitor Page 4",											// 0x83
	"Power Page 1",												// 0x84
	"Power Page 2",												// 0x85
	"Power Page 3",												// 0x86
	"Power Page 4",												// 0x87
	"(Reserved)",												// 0x88
	"(Reserved)",												// 0x89
	"(Reserved)",												// 0x8A
	"(Reserved)",												// 0x8B
	"Bar Code Scanner Page",									// 0x8C
	"Scale Page",												// 0x8D
	"Magnetic Stripe Reading Devices",							// 0x8E
	"Reserved Point of Sale Page",								// 0x8F
	"Camera Control Page",										// 0x90
	"Arcade Page",												// 0x91
};

static const usageInfo usagePage01[] = {
	{ "(Undefined)", None },									// 0x00
	{ "Pointer", PhysicalCollection },							// 0x01
	{ "Mouse", ApplicationCollection },							// 0x02
	{ "(Reserved)", None },										// 0x03
	{ "Joystick", ApplicationCollection },						// 0x04
	{ "Game Pad", ApplicationCollection },						// 0x05
	{ "Keyboard", ApplicationCollection },						// 0x06
	{ "Keypad", ApplicationCollection },						// 0x07
	{ "Multi-axis Controller", ApplicationCollection},			// 0x08
	{ "Tablet PC System Controls", ApplicationCollection},		// 0x09
	{ "(Reserved)", None },										// 0x0A
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x10
	{ "(Reserved)", None },										// 0x11
	{ "(Reserved)", None },										// 0x12
	{ "(Reserved)", None },										// 0x13
	{ "(Reserved)", None },										// 0x14
	{ "(Reserved)", None },										// 0x15
	{ "(Reserved)", None },										// 0x16
	{ "(Reserved)", None },										// 0x17
	{ "(Reserved)", None },										// 0x18
	{ "(Reserved)", None },										// 0x19
	{ "(Reserved)", None },										// 0x1A
	{ "(Reserved)", None },										// 0x1B
	{ "(Reserved)", None },										// 0x1C
	{ "(Reserved)", None },										// 0x1D
	{ "(Reserved)", None },										// 0x1E
	{ "(Reserved)", None },										// 0x1F
	{ "(Reserved)", None },										// 0x20
	{ "(Reserved)", None },										// 0x21
	{ "(Reserved)", None },										// 0x22
	{ "(Reserved)", None },										// 0x23
	{ "(Reserved)", None },										// 0x24
	{ "(Reserved)", None },										// 0x25
	{ "(Reserved)", None },										// 0x26
	{ "(Reserved)", None },										// 0x27
	{ "(Reserved)", None },										// 0x28
	{ "(Reserved)", None },										// 0x29
	{ "(Reserved)", None },										// 0x2A
	{ "(Reserved)", None },										// 0x2B
	{ "(Reserved)", None },										// 0x2C
	{ "(Reserved)", None },										// 0x2D
	{ "(Reserved)", None },										// 0x2E
	{ "(Reserved)", None },										// 0x2F
	{ "X", DynamicValue },										// 0x30
	{ "Y", DynamicValue },										// 0x31
	{ "Z", DynamicValue },										// 0x32
	{ "Rx", DynamicValue },										// 0x33
	{ "Ry", DynamicValue },										// 0x34
	{ "Rz", DynamicValue },										// 0x35
	{ "Slider", DynamicValue },									// 0x36
	{ "Dial", DynamicValue },									// 0x37
	{ "Wheel", DynamicValue },									// 0x38
	{ "Hat Switch", DynamicValue },								// 0x39
	{ "Counted Buffer", LogicalCollection },					// 0x3A
	{ "Byte Count", DynamicValue },								// 0x3B
	{ "Motion Wakeup", OneShotControl },						// 0x3C
	{ "Start", OnOffControl },									// 0x3D
	{ "Select", OnOffControl },									// 0x3E
	{ "(Reserved)", None },										// 0x3F
	{ "Vx", DynamicValue },										// 0x40
	{ "Vy", DynamicValue },										// 0x41
	{ "Vz", DynamicValue },										// 0x42
	{ "Vbrx", DynamicValue },									// 0x43
	{ "Vbry", DynamicValue },									// 0x44
	{ "Vbrz", DynamicValue },									// 0x45
	{ "Vno", DynamicValue },									// 0x46
	{ "Feature Notification", DynamicValue },					// 0x47
	{ "Resolution Mutiplier", DynamicValue },					// 0x48
	{ "(Reserved)", None },										// 0x49
	{ "(Reserved)", None },										// 0x4A
	{ "(Reserved)", None },										// 0x4B
	{ "(Reserved)", None },										// 0x4C
	{ "(Reserved)", None },										// 0x4D
	{ "(Reserved)", None },										// 0x4E
	{ "(Reserved)", None },										// 0x4F
	{ "(Reserved)", None },										// 0x50
	{ "(Reserved)", None },										// 0x51
	{ "(Reserved)", None },										// 0x52
	{ "(Reserved)", None },										// 0x53
	{ "(Reserved)", None },										// 0x54
	{ "(Reserved)", None },										// 0x55
	{ "(Reserved)", None },										// 0x56
	{ "(Reserved)", None },										// 0x57
	{ "(Reserved)", None },										// 0x58
	{ "(Reserved)", None },										// 0x59
	{ "(Reserved)", None },										// 0x5A
	{ "(Reserved)", None },										// 0x5B
	{ "(Reserved)", None },										// 0x5C
	{ "(Reserved)", None },										// 0x5D
	{ "(Reserved)", None },										// 0x5E
	{ "(Reserved)", None },										// 0x5F
	{ "(Reserved)", None },										// 0x60
	{ "(Reserved)", None },										// 0x61
	{ "(Reserved)", None },										// 0x62
	{ "(Reserved)", None },										// 0x63
	{ "(Reserved)", None },										// 0x64
	{ "(Reserved)", None },										// 0x65
	{ "(Reserved)", None },										// 0x66
	{ "(Reserved)", None },										// 0x67
	{ "(Reserved)", None },										// 0x68
	{ "(Reserved)", None },										// 0x69
	{ "(Reserved)", None },										// 0x6A
	{ "(Reserved)", None },										// 0x6B
	{ "(Reserved)", None },										// 0x6C
	{ "(Reserved)", None },										// 0x6D
	{ "(Reserved)", None },										// 0x6E
	{ "(Reserved)", None },										// 0x6F
	{ "(Reserved)", None },										// 0x70
	{ "(Reserved)", None },										// 0x71
	{ "(Reserved)", None },										// 0x72
	{ "(Reserved)", None },										// 0x73
	{ "(Reserved)", None },										// 0x74
	{ "(Reserved)", None },										// 0x75
	{ "(Reserved)", None },										// 0x76
	{ "(Reserved)", None },										// 0x77
	{ "(Reserved)", None },										// 0x78
	{ "(Reserved)", None },										// 0x79
	{ "(Reserved)", None },										// 0x7A
	{ "(Reserved)", None },										// 0x7B
	{ "(Reserved)", None },										// 0x7C
	{ "(Reserved)", None },										// 0x7D
	{ "(Reserved)", None },										// 0x7E
	{ "(Reserved)", None },										// 0x7F
	{ "System Control", ApplicationCollection },				// 0x80
	{ "System Power Down", OneShotControl },					// 0x81
	{ "System Sleep", OneShotControl },							// 0x82
	{ "System Wake Up", OneShotControl },						// 0x83
	{ "System Context Menu", OneShotControl },					// 0x84
	{ "System Main Menu", OneShotControl },						// 0x85
	{ "System App Menu", OneShotControl },						// 0x86
	{ "System Menu Help", OneShotControl },						// 0x87
	{ "System Menu Exit", OneShotControl },						// 0x88
	{ "System Menu Select", OneShotControl },					// 0x89
	{ "System Menu Right", RetriggerControl },					// 0x8A
	{ "System Menu Left", RetriggerControl },					// 0x8B
	{ "System Menu Up", RetriggerControl },						// 0x8C
	{ "System Menu Down", RetriggerControl },					// 0x8D
	{ "System Cold Restart", OneShotControl },					// 0x8E
	{ "System Warm Restart", OneShotControl },					// 0x8F
	{ "D-pad Up", OnOffControl },								// 0x90
	{ "D-pad Down", OnOffControl },								// 0x91
	{ "D-pad Right", OnOffControl },							// 0x92
	{ "D-pad Left", OnOffControl },								// 0x93
	{ "(Reserved)", None },										// 0x94
	{ "(Reserved)", None },										// 0x95
	{ "(Reserved)", None },										// 0x96
	{ "(Reserved)", None },										// 0x97
	{ "(Reserved)", None },										// 0x98
	{ "(Reserved)", None },										// 0x99
	{ "(Reserved)", None },										// 0x9A
	{ "(Reserved)", None },										// 0x9B
	{ "(Reserved)", None },										// 0x9C
	{ "(Reserved)", None },										// 0x9D
	{ "(Reserved)", None },										// 0x9E
	{ "(Reserved)", None },										// 0x9F
	{ "System Dock", OneShotControl },							// 0xA0
	{ "System Undock", OneShotControl },						// 0xA1
	{ "System Setup", OneShotControl },							// 0xA2
	{ "System Break", OneShotControl },							// 0xA3
	{ "System Debugger Break", OneShotControl },				// 0xA4
	{ "Application Break", OneShotControl },					// 0xA5
	{ "Application Debugger Break", OneShotControl },			// 0xA6
	{ "System Speaker Mute", OneShotControl },					// 0xA7
	{ "System Hibernate", OneShotControl },						// 0xA8
	{ "(Reserved)", None },										// 0xA9
	{ "(Reserved)", None },										// 0xAA
	{ "(Reserved)", None },										// 0xAB
	{ "(Reserved)", None },										// 0xAC
	{ "(Reserved)", None },										// 0xAD
	{ "(Reserved)", None },										// 0xAE
	{ "(Reserved)", None },										// 0xAF
	{ "System Display Invert", OneShotControl },				// 0xB0
	{ "System Display Internal", OneShotControl },				// 0xB1
	{ "System Display External", OneShotControl },				// 0xB2
	{ "System Display Both", OneShotControl },					// 0xB3
	{ "System Display Dual", OneShotControl },					// 0xB4
	{ "System Display Toggle Int/Ext", OneShotControl },		// 0xB5
	{ "System Display Swap Primary/Secondary", OneShotControl },// 0xB6
	{ "System Display LCD Autoscale", OneShotControl },			// 0xB7
};
	
static const usageInfo usagePage02_1[] = {
	{ "(Undefined)", None },										// 0x00
	{ "Flight Simulation Device", ApplicationCollection },		// 0x01
	{ "Automobile Simulation Device", ApplicationCollection },  // 0x02
	{ "Tank Simulation Device", ApplicationCollection },		// 0x03
	{ "Spaceship Simulation Device", ApplicationCollection },   // 0x04
	{ "Submarine Simulation Device", ApplicationCollection },   // 0x05
	{ "Sailing Simulation Device", ApplicationCollection },     // 0x06
	{ "Motorcycle Simulation Device", ApplicationCollection },  // 0x07
	{ "Sports Simulation Device", ApplicationCollection },		// 0x08
	{ "Airplane Simulation Device", ApplicationCollection },    // 0x09
	{ "Helicopter Simulation Device", ApplicationCollection },  // 0x0A
	{ "Magic Carpet Simulation Device", ApplicationCollection },// 0x0B
	{ "Bicycle Simulation Device", ApplicationCollection },		// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x10
	{ "(Reserved)", None },										// 0x11
	{ "(Reserved)", None },										// 0x12
	{ "(Reserved)", None },										// 0x13
	{ "(Reserved)", None },										// 0x14
	{ "(Reserved)", None },										// 0x15
	{ "(Reserved)", None },										// 0x16
	{ "(Reserved)", None },										// 0x17
	{ "(Reserved)", None },										// 0x18
	{ "(Reserved)", None },										// 0x19
	{ "(Reserved)", None },										// 0x1A
	{ "(Reserved)", None },										// 0x1B
	{ "(Reserved)", None },										// 0x1C
	{ "(Reserved)", None },										// 0x1D
	{ "(Reserved)", None },										// 0x1E
	{ "(Reserved)", None },										// 0x1F
	{ "Flight Control Stick", ApplicationCollection },			// 0x20
	{ "Flight Stick", ApplicationCollection },					// 0x21
	{ "Cyclic Control", PhysicalCollection },					// 0x22
	{ "Cyclic Trim", PhysicalCollection },						// 0x23
	{ "Flight Yoke", ApplicationCollection },					// 0x24
	{ "Track Control", PhysicalCollection },					// 0x25
};

static const usageInfo usagePage02_2[] = {
	{ "Aileron", DynamicValue },								// 0xB0
	{ "Aileron Trim", DynamicValue },							// 0xB1
	{ "Anti-Torque Control", DynamicValue },					// 0xB2
	{ "Autopilot Enable", OnOffControl },						// 0xB3
	{ "Chaff Release", OneShotControl },						// 0xB4
	{ "Collective Control", DynamicValue },						// 0xB5
	{ "Dive Brake", DynamicValue },								// 0xB6
	{ "Electronic Countermeasures", OnOffControl },				// 0xB7
	{ "Elevator", DynamicValue },								// 0xB8
	{ "Elevator Trim", DynamicValue },							// 0xB9
	{ "Rudder", DynamicValue },									// 0xBA
	{ "Throttle", DynamicValue },								// 0xBB
	{ "Flight Communications", OnOffControl },					// 0xBC
	{ "Flare Release", OneShotControl },						// 0xBD
	{ "Landing Gear", OnOffControl },							// 0xBE
	{ "Toe Brake", DynamicValue },								// 0xBF
	{ "Trigger", MomentaryControl },							// 0xC0
	{ "Weapons Arm", OnOffControl },							// 0xC1
	{ "Weapons Select", OneShotControl },						// 0xC2
	{ "Wing Flaps", DynamicValue },								// 0xC3
	{ "Accelerator", DynamicValue },							// 0xC4
	{ "Brake", DynamicValue },									// 0xC5
	{ "Clutch", DynamicValue },									// 0xC6
	{ "Shifter", DynamicValue },								// 0xC7
	{ "Steering", DynamicValue },								// 0xC8
	{ "Turret Direction", DynamicValue },						// 0xC9
	{ "Barrel Elevation", DynamicValue },						// 0xCA
	{ "Dive Plane", DynamicValue },								// 0xCB
	{ "Ballast", DynamicValue },								// 0xCC
	{ "Bicycle Crank", DynamicValue },							// 0xCD
	{ "Handle Bars", DynamicValue },							// 0xCE
	{ "Front Brake", DynamicValue },							// 0xCF
	{ "Rear Brake", DynamicValue },								// 0xD0
};

static const usageInfo usagePage03[] = {
	{ "(Undefined)", None },									// 0x00
	{ "Belt", ApplicationCollection },							// 0x01
	{ "Body Suit", ApplicationCollection },						// 0x02
	{ "Flexor", PhysicalCollection },							// 0x03
	{ "Glove", PhysicalCollection },							// 0x04
	{ "Head Tracker", PhysicalCollection },						// 0x05
	{ "Head Mounted Display", ApplicationCollection },			// 0x06
	{ "Hand Tracker", ApplicationCollection },					// 0x07
	{ "Oculometer", ApplicationCollection },					// 0x08
	{ "Vest", ApplicationCollection },							// 0x09
	{ "Animatronic Device", ApplicationCollection },			// 0x0A
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x10
	{ "(Reserved)", None },										// 0x11
	{ "(Reserved)", None },										// 0x12
	{ "(Reserved)", None },										// 0x13
	{ "(Reserved)", None },										// 0x14
	{ "(Reserved)", None },										// 0x15
	{ "(Reserved)", None },										// 0x16
	{ "(Reserved)", None },										// 0x17
	{ "(Reserved)", None },										// 0x18
	{ "(Reserved)", None },										// 0x19
	{ "(Reserved)", None },										// 0x1A
	{ "(Reserved)", None },										// 0x1B
	{ "(Reserved)", None },										// 0x1C
	{ "(Reserved)", None },										// 0x1D
	{ "(Reserved)", None },										// 0x1E
	{ "(Reserved)", None },										// 0x1F
	{ "Stereo Enable", OnOffControl },							// 0x20
	{ "Display Enable", OnOffControl },							// 0x21
};

static const usageInfo usagePage04[] = {
	{ "(Undefined)", None },									// 0x00
	{ "Baseball Bat", ApplicationCollection },					// 0x01
	{ "Golf Club", ApplicationCollection },						// 0x02
	{ "Rowing Machine", ApplicationCollection },				// 0x03
	{ "Treadmill", ApplicationCollection },						// 0x04
	{ "(Reserved)", None },										// 0x05
	{ "(Reserved)", None },										// 0x06
	{ "(Reserved)", None },										// 0x07
	{ "(Reserved)", None },										// 0x08
	{ "(Reserved)", None },										// 0x09
	{ "(Reserved)", None },										// 0x0A
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x10
	{ "(Reserved)", None },										// 0x11
	{ "(Reserved)", None },										// 0x12
	{ "(Reserved)", None },										// 0x13
	{ "(Reserved)", None },										// 0x14
	{ "(Reserved)", None },										// 0x15
	{ "(Reserved)", None },										// 0x16
	{ "(Reserved)", None },										// 0x17
	{ "(Reserved)", None },										// 0x18
	{ "(Reserved)", None },										// 0x19
	{ "(Reserved)", None },										// 0x1A
	{ "(Reserved)", None },										// 0x1B
	{ "(Reserved)", None },										// 0x1C
	{ "(Reserved)", None },										// 0x1D
	{ "(Reserved)", None },										// 0x1E
	{ "(Reserved)", None },										// 0x1F
	{ "(Reserved)", None },										// 0x20
	{ "(Reserved)", None },										// 0x21
	{ "(Reserved)", None },										// 0x22
	{ "(Reserved)", None },										// 0x23
	{ "(Reserved)", None },										// 0x24
	{ "(Reserved)", None },										// 0x25
	{ "(Reserved)", None },										// 0x26
	{ "(Reserved)", None },										// 0x27
	{ "(Reserved)", None },										// 0x28
	{ "(Reserved)", None },										// 0x29
	{ "(Reserved)", None },										// 0x2A
	{ "(Reserved)", None },										// 0x2B
	{ "(Reserved)", None },										// 0x2C
	{ "(Reserved)", None },										// 0x2D
	{ "(Reserved)", None },										// 0x2E
	{ "(Reserved)", None },										// 0x2F
	{ "Oar", DynamicValue },									// 0x30
	{ "Slope", DynamicValue },									// 0x31
	{ "Rate", DynamicValue },									// 0x32
	{ "Stick Speed", DynamicValue },							// 0x33
	{ "Stick Face Angle", DynamicValue },						// 0x34
	{ "Stick Heel/Toe", DynamicValue },							// 0x35
	{ "Stick Follow Through", DynamicValue },					// 0x36
	{ "Stick Tempo", DynamicValue },							// 0x37
	{ "Stick Type", NamedArray },								// 0x38
	{ "Stick Height", DynamicValue },							// 0x39
	{ "(Reserved)", None },										// 0x3A
	{ "(Reserved)", None },										// 0x3B
	{ "(Reserved)", None },										// 0x3C
	{ "(Reserved)", None },										// 0x3D
	{ "(Reserved)", None },										// 0x3E
	{ "(Reserved)", None },										// 0x3F
	{ "(Reserved)", None },										// 0x40
	{ "(Reserved)", None },										// 0x41
	{ "(Reserved)", None },										// 0x42
	{ "(Reserved)", None },										// 0x43
	{ "(Reserved)", None },										// 0x44
	{ "(Reserved)", None },										// 0x45
	{ "(Reserved)", None },										// 0x46
	{ "(Reserved)", None },										// 0x47
	{ "(Reserved)", None },										// 0x48
	{ "(Reserved)", None },										// 0x49
	{ "(Reserved)", None },										// 0x4A
	{ "(Reserved)", None },										// 0x4B
	{ "(Reserved)", None },										// 0x4C
	{ "(Reserved)", None },										// 0x4D
	{ "(Reserved)", None },										// 0x4E
	{ "(Reserved)", None },										// 0x4F
	{ "Putter", Selector },										// 0x50
	{ "1 Iron", Selector },										// 0x51
	{ "2 Iron", Selector },										// 0x52
	{ "3 Iron", Selector },										// 0x53
	{ "4 Iron", Selector },										// 0x54
	{ "5 Iron", Selector },										// 0x55
	{ "6 Iron", Selector },										// 0x56
	{ "7 Iron", Selector },										// 0x57
	{ "8 Iron", Selector },										// 0x58
	{ "9 Iron", Selector },										// 0x59
	{ "10 Iron", Selector },									// 0x5A
	{ "11 Iron", Selector },									// 0x5B
	{ "Sand Wedge", Selector },									// 0x5C
	{ "Loft Wedge", Selector },									// 0x5D
	{ "Power Wedge", Selector },								// 0x5E
	{ "1 Wood", Selector },										// 0x5F
	{ "3 Wood", Selector },										// 0x60
	{ "5 Wood", Selector },										// 0x61
	{ "7 Wood", Selector },										// 0x62
	{ "9 Wood", Selector },										// 0x63
};

static const usageInfo usagePage05[] = {
	{ "(Undefined)", None },									// 0x00
	{ "3D Game Controller", ApplicationCollection },			// 0x01
	{ "Pinball Device", ApplicationCollection },				// 0x02
	{ "Gun Device", ApplicationCollection },					// 0x03
	{ "(Reserved)", None },										// 0x04
	{ "(Reserved)", None },										// 0x05
	{ "(Reserved)", None },										// 0x06
	{ "(Reserved)", None },										// 0x07
	{ "(Reserved)", None },										// 0x08
	{ "(Reserved)", None },										// 0x09
	{ "(Reserved)", None },										// 0x0A
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x10
	{ "(Reserved)", None },										// 0x11
	{ "(Reserved)", None },										// 0x12
	{ "(Reserved)", None },										// 0x13
	{ "(Reserved)", None },										// 0x14
	{ "(Reserved)", None },										// 0x15
	{ "(Reserved)", None },										// 0x16
	{ "(Reserved)", None },										// 0x17
	{ "(Reserved)", None },										// 0x18
	{ "(Reserved)", None },										// 0x19
	{ "(Reserved)", None },										// 0x1A
	{ "(Reserved)", None },										// 0x1B
	{ "(Reserved)", None },										// 0x1C
	{ "(Reserved)", None },										// 0x1D
	{ "(Reserved)", None },										// 0x1E
	{ "(Reserved)", None },										// 0x1F
	{ "Point of View", PhysicalCollection },					// 0x20
	{ "Turn Right/Left", DynamicValue },						// 0x21
	{ "Pitch Forward/Backward", DynamicValue },					// 0x22
	{ "Roll Right/Left", DynamicValue },						// 0x23
	{ "Move Right/Left", DynamicValue },						// 0x24
	{ "Move Forward/Backward", DynamicValue },					// 0x25
	{ "Move Up/Down", DynamicValue },							// 0x26
	{ "Lean Right/Left", DynamicValue },						// 0x27
	{ "Lean Forward/Backward", DynamicValue },					// 0x28
	{ "Height of POV", DynamicValue },							// 0x29
	{ "Flipper", MomentaryControl },							// 0x2A
	{ "Secondary Flipper", MomentaryControl },					// 0x2B
	{ "Bump", MomentaryControl },								// 0x2C
	{ "New Game", OneShotControl },								// 0x2D
	{ "Shoot Ball", OneShotControl },							// 0x2E
	{ "Player", OneShotControl },								// 0x2F
	{ "Gun Bolt", OnOffControl },								// 0x30
	{ "Gun Clip", OnOffControl },								// 0x31
	{ "Gun Selector", NamedArray },								// 0x32
	{ "Gun Single Shot", Selector },							// 0x33
	{ "Gun Burst", Selector },									// 0x34
	{ "Gun Automatic", Selector },								// 0x35
	{ "Gun Safety", Selector },									// 0x36
	{ "Gamepad Fire/Jump", LogicalCollection },					// 0x37
	{ "(Reserved)", None },										// 0x38
	{ "Gamepad Trigger", LogicalCollection },					// 0x39
};

static const usageInfo usagePage06[] = {
	{ "(Undefined)", None },									// 0x00
	{ "(Reserved)", None },										// 0x01
	{ "(Reserved)", None },										// 0x02
	{ "(Reserved)", None },										// 0x03
	{ "(Reserved)", None },										// 0x04
	{ "(Reserved)", None },										// 0x05
	{ "(Reserved)", None },										// 0x06
	{ "(Reserved)", None },										// 0x07
	{ "(Reserved)", None },										// 0x08
	{ "(Reserved)", None },										// 0x09
	{ "(Reserved)", None },										// 0x0A
	{ "(Reserved)", None },										// 0x0B
	{ "(Reserved)", None },										// 0x0C
	{ "(Reserved)", None },										// 0x0D
	{ "(Reserved)", None },										// 0x0E
	{ "(Reserved)", None },										// 0x0F
	{ "(Reserved)", None },										// 0x10
	{ "(Reserved)", None },										// 0x11
	{ "(Reserved)", None },										// 0x12
	{ "(Reserved)", None },										// 0x13
	{ "(Reserved)", None },										// 0x14
	{ "(Reserved)", None },										// 0x15
	{ "(Reserved)", None },										// 0x16
	{ "(Reserved)", None },										// 0x17
	{ "(Reserved)", None },										// 0x18
	{ "(Reserved)", None },										// 0x19
	{ "(Reserved)", None },										// 0x1A
	{ "(Reserved)", None },										// 0x1B
	{ "(Reserved)", None },										// 0x1C
	{ "(Reserved)", None },										// 0x1D
	{ "(Reserved)", None },										// 0x1E
	{ "(Reserved)", None },										// 0x1F
	{ "Battery Strength", DynamicValue },						// 0x20
	{ "Wireless Channel", DynamicValue },						// 0x21
	{ "Wireless ID", DynamicValue },							// 0x22
	{ "Discover Wireless Control", OneShotControl },			// 0x23
	{ "Security Code Character Entered", OneShotControl },		// 0x24
	{ "Security Code Character Erased", OneShotControl },		// 0x25
	{ "Security Code Cleared", OneShotControl },				// 0x26
};

static const usageInfo usagePage07[] = {
	{ "(no event indicated)", Selector },						// 0x00
	{ "Keyboard ErrorRollOver", Selector },						// 0x01
	{ "Keyboard POSTFail", Selector },							// 0x02
	{ "Keyboard ErrorUndefined", Selector },					// 0x03
	{ "Keyboard A", Selector },									// 0x04
	{ "Keyboard B", Selector },									// 0x05
	{ "Keyboard C", Selector },									// 0x06
	{ "Keyboard D", Selector },									// 0x07
	{ "Keyboard E", Selector },									// 0x08
	{ "Keyboard F", Selector },									// 0x09
	{ "Keyboard G", Selector },									// 0x0A
	{ "Keyboard H", Selector },									// 0x0B
	{ "Keyboard I", Selector },									// 0x0C
	{ "Keyboard J", Selector },									// 0x0D
	{ "Keyboard K", Selector },									// 0x0E
	{ "Keyboard L", Selector },									// 0x0F
	{ "Keyboard M", Selector },									// 0x10
	{ "Keyboard N", Selector },									// 0x11
	{ "Keyboard O", Selector },									// 0x12
	{ "Keyboard P", Selector },									// 0x13
	{ "Keyboard Q", Selector },									// 0x14
	{ "Keyboard R", Selector },									// 0x15
	{ "Keyboard S", Selector },									// 0x16
	{ "Keyboard T", Selector },									// 0x17
	{ "Keyboard U", Selector },									// 0x18
	{ "Keyboard V", Selector },									// 0x19
	{ "Keyboard W", Selector },									// 0x1A
	{ "Keyboard X", Selector },									// 0x1B
	{ "Keyboard Y", Selector },									// 0x1C
	{ "Keyboard Z", Selector },									// 0x1D
	{ "Keyboard 1/!", Selector },								// 0x1E
	{ "Keyboard 2/@", Selector },								// 0x1F
	{ "Keyboard 3/#", Selector },								// 0x20
	{ "Keyboard 4/$", Selector },								// 0x21
	{ "Keyboard 5/%", Selector },								// 0x22
	{ "Keyboard 6/^", Selector },								// 0x23
	{ "Keyboard 7/&", Selector },								// 0x24
	{ "Keyboard 8/*", Selector },								// 0x25
	{ "Keyboard 9/(", Selector },								// 0x26
	{ "Keyboard 0/)", Selector },								// 0x27
	{ "Keyboard Return", Selector },							// 0x28
	{ "Keyboard Escape", Selector },							// 0x29
	{ "Keyboard Delete", Selector },							// 0x2A
	{ "Keyboard Tab", Selector },								// 0x2B
	{ "Keyboard Spacebar", Selector },							// 0x2C
	{ "Keyboard -/_", Selector },								// 0x2D
	{ "Keyboard =/+", Selector },								// 0x2E
	{ "Keyboard [/{", Selector },								// 0x2F
	{ "Keyboard ]/}", Selector },								// 0x30
	{ "Keyboard \\/|", Selector },								// 0x31
	{ "Keyboard Non-US #/~", Selector },						// 0x32
	{ "Keyboard ;/:", Selector },								// 0x33
	{ "Keyboard '/\"", Selector },								// 0x34
	{ "Keyboard `/~", Selector },								// 0x35
	{ "Keyboard ,/<", Selector },								// 0x36
	{ "Keyboard ./>", Selector },								// 0x37
	{ "Keyboard Cap Lock", Selector },							// 0x38
	{ "Keyboard //?", Selector },								// 0x39
	{ "Keyboard F1", Selector },								// 0x3A
	{ "Keyboard F2", Selector },								// 0x3B
	{ "Keyboard F3", Selector },								// 0x3C
	{ "Keyboard F4", Selector },								// 0x3D
	{ "Keyboard F5", Selector },								// 0x3E
	{ "Keyboard F6", Selector },								// 0x3F
	{ "Keyboard F7", Selector },								// 0x40
	{ "Keyboard F8", Selector },								// 0x41
	{ "Keyboard F9", Selector },								// 0x42
	{ "Keyboard F10", Selector },								// 0x43
	{ "Keyboard F11", Selector },								// 0x44
	{ "Keyboard F12", Selector },								// 0x45
	{ "Keyboard PrintScreen", Selector },						// 0x46
	{ "Keyboard Scroll Lock", Selector },						// 0x47
	{ "Keyboard Pause", Selector },								// 0x48
	{ "Keyboard Insert", Selector },							// 0x49
	{ "Keyboard Home", Selector },								// 0x4A
	{ "Keyboard PageUp", Selector },							// 0x4B
	{ "Keyboard Delete Forward", Selector },					// 0x4C
	{ "Keyboard End", Selector },								// 0x4D
	{ "Keyboard PageDown", Selector },							// 0x4E
	{ "Keyboard RightArrow", Selector },						// 0x4F
	{ "Keyboard LeftArrow", Selector },							// 0x50
	{ "Keyboard DownArrow", Selector },							// 0x51
	{ "Keyboard UpArrow", Selector },							// 0x52
	{ "Keyboard Num Lock/Clear", Selector },					// 0x53
	{ "Keypad / ", Selector },									// 0x54
	{ "Keypad *", Selector },									// 0x55
	{ "Keypad -", Selector },									// 0x56
	{ "Keypad +", Selector },									// 0x57
	{ "Keypad ENTER", Selector },								// 0x58
	{ "Keypad 1/End", Selector },								// 0x59
	{ "Keypad 2/Down Arrow", Selector },						// 0x5A
	{ "Keypad 3/PageDn", Selector },							// 0x5B
	{ "Keypad 4/Left Arrow", Selector },						// 0x5C
	{ "Keypad 5", Selector },									// 0x5D
	{ "Keypad 6/Right Arrow", Selector },						// 0x5E
	{ "Keypad 7/Home", Selector },								// 0x5F
	{ "Keypad 8/Up Arrow", Selector },							// 0x60
	{ "Keypad 9/PageUp", Selector },							// 0x61
	{ "Keypad 0/Insert", Selector },							// 0x62
	{ "Keypad ./Delete", Selector },							// 0x63
	{ "Keypad Non-US \\ and |", Selector },						// 0x64
	{ "Keyboard Application", Selector },						// 0x65
	{ "Keyboard Power", Selector },								// 0x66
	{ "Keyboard =", Selector },									// 0x67
	{ "Keyboard F13", Selector },								// 0x68
	{ "Keyboard F14", Selector },								// 0x69
	{ "Keyboard F15", Selector },								// 0x6A
	{ "Keyboard F16", Selector },								// 0x6B
	{ "Keyboard F17", Selector },								// 0x6C
	{ "Keyboard F18", Selector },								// 0x6D
	{ "Keyboard F19", Selector },								// 0x6E
	{ "Keyboard F20", Selector },								// 0x6F
	{ "Keyboard F21", Selector },								// 0x70
	{ "Keyboard F22", Selector },								// 0x71
	{ "Keyboard F23", Selector },								// 0x72
	{ "Keyboard F24", Selector },								// 0x73
	{ "Keyboard Execute", Selector },							// 0x74
	{ "Keyboard Help", Selector },								// 0x75
	{ "Keyboard Menu", Selector },								// 0x76
	{ "Keyboard Select", Selector },							// 0x77
	{ "Keyboard Stop", Selector },								// 0x78
	{ "Keyboard Again", Selector },								// 0x79
	{ "Keyboard Undo", Selector },								// 0x7A
	{ "Keyboard Cut", Selector },								// 0x7B
	{ "Keyboard Copy", Selector },								// 0x7C
	{ "Keyboard Paste", Selector },								// 0x7D
	 { "Keyboard Find", Selector },								// 0x7E
	 { "Keyboard Mute", Selector },								// 0x7F
	 { "Keyboard Volume Up", Selector },						// 0x80
	 { "Keyboard Volume Down", Selector },						// 0x81
	 { "Keyboard Locking Caps Lock", Selector },				// 0x82
	 { "Keyboard Locking Num Lock", Selector },					// 0x83
	 { "Keyboard Locking Scroll Lock", Selector },				// 0x84
	 { "Keyboard Comma", Selector },							// 0x85
	 { "Keyboard Equal Sign", Selector },						// 0x86
	 { "Keyboard International1", Selector },					// 0x87
	 { "Keyboard International2", Selector },					// 0x88
	 { "Keyboard International3", Selector },					// 0x89
	 { "Keyboard International4", Selector },					// 0x8A
	 { "Keyboard International5", Selector },					// 0x8B
	 { "Keyboard International6", Selector },					// 0x8C
	 { "Keyboard International7", Selector },					// 0x8D
	 { "Keyboard International8", Selector },					// 0x8E
	 { "Keyboard International9", Selector },					// 0x8F
	 { "Keyboard LANG1", Selector },							// 0x90
	 { "Keyboard LANG2", Selector },							// 0x91
	 { "Keyboard LANG3", Selector },							// 0x92
	 { "Keyboard LANG4", Selector },							// 0x93
	 { "Keyboard LANG5", Selector },							// 0x94
	 { "Keyboard LANG6", Selector },							// 0x95
	 { "Keyboard LANG7", Selector },							// 0x96
	 { "Keyboard LANG8", Selector },							// 0x97
	 { "Keyboard LANG9", Selector },							// 0x98
	 { "Keyboard Alternate Erase", Selector },					// 0x99
	 { "Keyboard SysReq/Attention", Selector },					// 0x9A
	 { "Keyboard Cancel", Selector },							// 0x9B
	 { "Keyboard Clear", Selector },							// 0x9C
	 { "Keyboard Prior", Selector },							// 0x9D
	 { "Keyboard Return", Selector },							// 0x9E
	 { "Keyboard Separator", Selector },						// 0x9F
	 { "Keyboard Out", Selector },								// 0xA0
	 { "Keyboard Oper", Selector },								// 0xA1
	 { "Keyboard Clear/Again", Selector },						// 0xA2
	 { "Keyboard CrSel/Props", Selector },						// 0xA3
	 { "Keyboard ExSel", Selector },							// 0xA4
	 { "(Reserved)", None },									// 0xA5
	 { "(Reserved)", None },									// 0xA6
	 { "(Reserved)", None },									// 0xA7
	 { "(Reserved)", None },									// 0xA8
	 { "(Reserved)", None },									// 0xA9
	 { "(Reserved)", None },									// 0xAA
	 { "(Reserved)", None },									// 0xAB
	 { "(Reserved)", None },									// 0xAC
	 { "(Reserved)", None },									// 0xAD
	 { "(Reserved)", None },									// 0xAE
	 { "(Reserved)", None },									// 0xAF
	 { "Keypad 00", Selector },									// 0xB0
	 { "Keypad 000", Selector },								// 0xB1
	 { "Thousands Separator", Selector },						// 0xB2
	 { "Decimal Separator", Selector },							// 0xB3
	 { "Currency Unit", Selector },								// 0xB4
	 { "Currency Sub-unit", Selector },							// 0xB5
	 { "Keypad (", Selector },									// 0xB6
	 { "Keypad )", Selector },									// 0xB7
	 { "Keypad {", Selector },									// 0xB8
	 { "Keypad }", Selector },									// 0xB9
	 { "Keypad Tab", Selector },								// 0xBA
	 { "Keypad Backspace", Selector },							// 0xBB
	 { "Keypad A", Selector },									// 0xBC
	 { "Keypad B", Selector },									// 0xBD
	 { "Keypad C", Selector },									// 0xBE
	 { "Keypad D", Selector },									// 0xBF
	 { "Keypad E", Selector },									// 0xC0
	 { "Keypad F", Selector },									// 0xC1
	 { "Keypad XOR", Selector },								// 0xC2
	 { "Keypad ^", Selector },									// 0xC3
	 { "Keypad %", Selector },									// 0xC4
	 { "Keypad <", Selector },									// 0xC5
	 { "Keypad >", Selector },									// 0xC6
	 { "Keypad &", Selector },									// 0xC7
	 { "Keypad &&", Selector },									// 0xC8
	 { "Keypad |", Selector },									// 0xC9
	 { "Keypad ||", Selector },									// 0xCA
	 { "Keypad :", Selector },									// 0xCB
	 { "Keypad #", Selector },									// 0xCC
	 { "Keypad Space", Selector },								// 0xCD
	 { "Keypad @", Selector },									// 0xCE
	 { "Keypad !", Selector },									// 0xCF
	 { "Keypad Memory Store", Selector },						// 0xD0
	 { "Keypad Memory Recall", Selector },						// 0xD1
	 { "Keypad Memory Clear", Selector },						// 0xD2
	 { "Keypad Memory Add", Selector },							// 0xD3
	 { "Keypad Memory Subtract", Selector },					// 0xD4
	 { "Keypad Memory Multiply", Selector },					// 0xD5
	 { "Keypad Memory Divide", Selector },						// 0xD6
	 { "Keypad +/-", Selector },								// 0xD7
	 { "Keypad Clear", Selector },								// 0xD8
	 { "Keypad Clear Entry", Selector },						// 0xD9
	 { "Keypad Binary", Selector },								// 0xDA
	 { "Keypad Octal", Selector },								// 0xDB
	 { "Keypad Decimal", Selector },							// 0xDC
	 { "Keypad Hexadecimal", Selector },						// 0xDD
	 { "(Reserved)", None },									// 0xDE
	 { "(Reserved)", None },									// 0xDF
	 { "Keyboard LeftControl", Selector },						// 0xE0
	 { "Keyboard LeftShift", Selector },						// 0xE1
	 { "Keyboard LeftAlt", Selector },							// 0xE2
	 { "Keyboard LeftGUI", Selector },							// 0xE3
	 { "Keyboard RightControl", Selector },						// 0xE4
	 { "Keyboard RightShift", Selector },						// 0xE5
	 { "Keyboard RightAlt", Selector },							// 0xE6
	 { "Keyboard RightGUI", Selector },							// 0xE7
};

static const usageInfo usagePage08[] = {
	{ "(Undefined)", None },											// 0x00
	{ "Num Lock", OnOffControl },										// 0x01
	{ "Caps Lock", OnOffControl },										// 0x02
	{ "Scroll Lock", OnOffControl },									// 0x03
	{ "Compose", OnOffControl },										// 0x04
	{ "Kana", OnOffControl },											// 0x05
	{ "Power", OnOffControl },											// 0x06
	{ "Shift", OnOffControl },											// 0x07
	{ "Do Not Disturb", OnOffControl },									// 0x08
	{ "Mute", OnOffControl },											// 0x09
	{ "Tone Enable", OnOffControl },									// 0x0A
	{ "High Cut Filter", OnOffControl },								// 0x0B
	{ "Low Cut Filter", OnOffControl },									// 0x0C
	{ "Equalizer Enable", OnOffControl },								// 0x0D
	{ "Sound Field On", OnOffControl },									// 0x0E
	{ "Surround On", OnOffControl },									// 0x0F
	{ "Repeat", OnOffControl },											// 0x10
	{ "Stereo", OnOffControl },											// 0x11
	{ "Sampling Rate Detect", OnOffControl },							// 0x12
	{ "Spinning", OnOffControl },										// 0x13
	{ "CAV", OnOffControl },											// 0x14
	{ "CLV", OnOffControl },											// 0x15
	{ "Recording Format Detect", OnOffControl },						// 0x16
	{ "Off-Hook", OnOffControl },										// 0x17
	{ "Ring", OnOffControl },											// 0x18
	{ "Message Waiting", OnOffControl },								// 0x19
	{ "Data Mode", OnOffControl },										// 0x1A
	{ "Battery Operation", OnOffControl },								// 0x1B
	{ "Battery OK", OnOffControl },										// 0x1C
	{ "Battery Low", OnOffControl },									// 0x1D
	{ "Speaker", OnOffControl },										// 0x1E
	{ "Head Set", OnOffControl },										// 0x1F
	{ "Hold", OnOffControl },											// 0x20
	{ "Microphone", OnOffControl },										// 0x21
	{ "Coverage", OnOffControl },										// 0x22
	{ "Night Mode", OnOffControl },										// 0x23
	{ "Send Calls", OnOffControl },										// 0x24
	{ "Call Pickup", OnOffControl },									// 0x25
	{ "Conference", OnOffControl },										// 0x26
	{ "Stand-by", OnOffControl },										// 0x27
	{ "Camera On", OnOffControl },										// 0x28
	{ "Camera Off", OnOffControl },										// 0x29
	{ "On-Line", OnOffControl },										// 0x2A
	{ "Off-Line", OnOffControl },										// 0x2B
	{ "Busy", OnOffControl },											// 0x2C
	{ "Ready", OnOffControl },											// 0x2D
	{ "Paper-Out", OnOffControl },										// 0x2E
	{ "Paper-Jam", OnOffControl },										// 0x2F
	{ "Remote", OnOffControl },											// 0x30
	{ "Forward", OnOffControl },										// 0x31
	{ "Reverse", OnOffControl },										// 0x32
	{ "Stop", OnOffControl },											// 0x33
	{ "Rewind", OnOffControl },											// 0x34
	{ "Fast Forward", OnOffControl },									// 0x35
	{ "Play", OnOffControl },											// 0x36
	{ "Pause", OnOffControl },											// 0x37
	{ "Record", OnOffControl },											// 0x38
	{ "Error", OnOffControl },											// 0x39
	{ "Usage Selected Indicator", UsageSwitch },						// 0x3A
	{ "Usage in Use Indicator", UsageSwitch },							// 0x3B
	{ "Usage Multi Mode Indicator", UsageModifier },					// 0x3C
	{ "Indicator On", Selector },										// 0x3D
	{ "Indicator Flash", Selector },									// 0x3E
	{ "Indicator Slow Blink", Selector },								// 0x3F
	{ "Indicator Fast Blink", Selector },								// 0x40
	{ "Indicator Off", Selector },										// 0x41
	{ "Flash On Time", DynamicValue },									// 0x42
	{ "Slow Blink On Time", DynamicValue },								// 0x43
	{ "Slow Blink Off Time", DynamicValue },							// 0x44
	{ "Fast Blink On Time", DynamicValue },								// 0x45
	{ "Fast Blink Off Time", DynamicValue },							// 0x46
	{ "Usage Indicator Color", UsageModifier },							// 0x47
	{ "Indicator Red", Selector },										// 0x48
	{ "Indicator Green", Selector },									// 0x49
	{ "Indicator Amber", Selector },									// 0x4A
	{ "Generic Indicator", OnOffControl },								// 0x4B
	{ "System Suspend", OnOffControl },									// 0x4C
	{ "External Power Connected", OnOffControl },						// 0x4D
};

static const usageInfo usagePage0B[] = {
	{ "(Unassigned)", None },											// 0x00
	{ "Phone", ApplicationCollection },									// 0x01
	{ "Answering Machine", ApplicationCollection },						// 0x02
	{ "Message Controls", LogicalCollection },							// 0x03
	{ "Handset", LogicalCollection },									// 0x04
	{ "Headset", LogicalCollection },									// 0x05
	{ "Telephony Key Pad", NamedArray },								// 0x06
	{ "Programmable Button", NamedArray },								// 0x07
	{ "(Reserved)", None },												// 0x08
	{ "(Reserved)", None },												// 0x09
	{ "(Reserved)", None },												// 0x0A
	{ "(Reserved)", None },												// 0x0B
	{ "(Reserved)", None },												// 0x0C
	{ "(Reserved)", None },												// 0x0D
	{ "(Reserved)", None },												// 0x0E
	{ "(Reserved)", None },												// 0x0F
	{ "(Reserved)", None },												// 0x10
	{ "(Reserved)", None },												// 0x11
	{ "(Reserved)", None },												// 0x12
	{ "(Reserved)", None },												// 0x13
	{ "(Reserved)", None },												// 0x14
	{ "(Reserved)", None },												// 0x15
	{ "(Reserved)", None },												// 0x16
	{ "(Reserved)", None },												// 0x17
	{ "(Reserved)", None },												// 0x18
	{ "(Reserved)", None },												// 0x19
	{ "(Reserved)", None },												// 0x1A
	{ "(Reserved)", None },												// 0x1B
	{ "(Reserved)", None },												// 0x1C
	{ "(Reserved)", None },												// 0x1D
	{ "(Reserved)", None },												// 0x1E
	{ "(Reserved)", None },												// 0x1F
	{ "Hook Switch", OnOffControl },									// 0x20
	{ "Flash", MomentaryControl },										// 0x21
	{ "Feature", OneShotControl },										// 0x22
	{ "Hold", OneShotControl },											// 0x23
	{ "Redial", OneShotControl },										// 0x24
	{ "Transfer", OneShotControl },										// 0x25
	{ "Drop", OneShotControl },											// 0x26
	{ "Park", OneShotControl },											// 0x27
	{ "Forward Calls", OneShotControl },								// 0x28
	{ "Alternate Function", MomentaryControl },							// 0x29
	{ "Line", OneShotControl },											// 0x2A
	{ "Speaker Phone", OnOffControl },									// 0x2B
	{ "Conference", OnOffControl },										// 0x2C
	{ "Ring Enable", OnOffControl },									// 0x2D
	{ "Ring Select", OneShotControl },									// 0x2E
	{ "Phone Mute", OnOffControl },										// 0x2F
	{ "Caller ID", MomentaryControl },									// 0x30
	{ "Send", OnOffControl },											// 0x31
	{ "(Reserved)", None },												// 0x32
	{ "(Reserved)", None },												// 0x33
	{ "(Reserved)", None },												// 0x34
	{ "(Reserved)", None },												// 0x35
	{ "(Reserved)", None },												// 0x36
	{ "(Reserved)", None },												// 0x37
	{ "(Reserved)", None },												// 0x38
	{ "(Reserved)", None },												// 0x39
	{ "(Reserved)", None },												// 0x3A
	{ "(Reserved)", None },												// 0x3B
	{ "(Reserved)", None },												// 0x3C
	{ "(Reserved)", None },												// 0x3D
	{ "(Reserved)", None },												// 0x3E
	{ "(Reserved)", None },												// 0x3F
	{ "(Reserved)", None },												// 0x40
	{ "(Reserved)", None },												// 0x41
	{ "(Reserved)", None },												// 0x42
	{ "(Reserved)", None },												// 0x43
	{ "(Reserved)", None },												// 0x44
	{ "(Reserved)", None },												// 0x45
	{ "(Reserved)", None },												// 0x46
	{ "(Reserved)", None },												// 0x47
	{ "(Reserved)", None },												// 0x48
	{ "(Reserved)", None },												// 0x49
	{ "(Reserved)", None },												// 0x4A
	{ "(Reserved)", None },												// 0x4B
	{ "(Reserved)", None },												// 0x4C
	{ "(Reserved)", None },												// 0x4D
	{ "(Reserved)", None },												// 0x4E
	{ "(Reserved)", None },												// 0x4F
	{ "Speed Dial", OneShotControl },									// 0x50
	{ "Store Number", OneShotControl },									// 0x51
	{ "Recall Number", OneShotControl },								// 0x52
	{ "Phone Directory", OnOffControl },								// 0x53
	{ "(Reserved)", None },												// 0x54
	{ "(Reserved)", None },												// 0x55
	{ "(Reserved)", None },												// 0x56
	{ "(Reserved)", None },												// 0x57
	{ "(Reserved)", None },												// 0x58
	{ "(Reserved)", None },												// 0x59
	{ "(Reserved)", None },												// 0x5A
	{ "(Reserved)", None },												// 0x5B
	{ "(Reserved)", None },												// 0x5C
	{ "(Reserved)", None },												// 0x5D
	{ "(Reserved)", None },												// 0x5E
	{ "(Reserved)", None },												// 0x5F
	{ "(Reserved)", None },												// 0x60
	{ "(Reserved)", None },												// 0x61
	{ "(Reserved)", None },												// 0x62
	{ "(Reserved)", None },												// 0x63
	{ "(Reserved)", None },												// 0x64
	{ "(Reserved)", None },												// 0x65
	{ "(Reserved)", None },												// 0x66
	{ "(Reserved)", None },												// 0x67
	{ "(Reserved)", None },												// 0x68
	{ "(Reserved)", None },												// 0x69
	{ "(Reserved)", None },												// 0x6A
	{ "(Reserved)", None },												// 0x6B
	{ "(Reserved)", None },												// 0x6C
	{ "(Reserved)", None },												// 0x6D
	{ "(Reserved)", None },												// 0x6E
	{ "(Reserved)", None },												// 0x6F
	{ "Voice Mail", OnOffControl },										// 0x70
	{ "Screen Calls", OnOffControl },									// 0x71
	{ "Do Not Disturb", OnOffControl },									// 0x72
	{ "Message", OneShotControl },										// 0x73
	{ "Answer On/Off", OnOffControl },									// 0x74
	{ "(Reserved)", None },												// 0x75
	{ "(Reserved)", None },												// 0x76
	{ "(Reserved)", None },												// 0x77
	{ "(Reserved)", None },												// 0x78
	{ "(Reserved)", None },												// 0x79
	{ "(Reserved)", None },												// 0x7A
	{ "(Reserved)", None },												// 0x7B
	{ "(Reserved)", None },												// 0x7C
	{ "(Reserved)", None },												// 0x7D
	{ "(Reserved)", None },												// 0x7E
	{ "(Reserved)", None },												// 0x7F
	{ "(Reserved)", None },												// 0x80
	{ "(Reserved)", None },												// 0x81
	{ "(Reserved)", None },												// 0x82
	{ "(Reserved)", None },												// 0x83
	{ "(Reserved)", None },												// 0x84
	{ "(Reserved)", None },												// 0x85
	{ "(Reserved)", None },												// 0x86
	{ "(Reserved)", None },												// 0x87
	{ "(Reserved)", None },												// 0x88
	{ "(Reserved)", None },												// 0x89
	{ "(Reserved)", None },												// 0x8A
	{ "(Reserved)", None },												// 0x8B
	{ "(Reserved)", None },												// 0x8C
	{ "(Reserved)", None },												// 0x8D
	{ "(Reserved)", None },												// 0x8E
	{ "(Reserved)", None },												// 0x8F
	{ "Inside Dial Tone", MomentaryControl },							// 0x90
	{ "Outside Dial Tone", MomentaryControl },							// 0x91
	{ "Inside Ring Tone", MomentaryControl },							// 0x92
	{ "Outside Ring Tone", MomentaryControl },							// 0x93
	{ "Priority Ring Tone", MomentaryControl },							// 0x94
	{ "Inside Ringback", MomentaryControl },							// 0x95
	{ "Priority Ringback", MomentaryControl },							// 0x96
	{ "Line Busy Tone", MomentaryControl },								// 0x97
	{ "Reorder Tone", MomentaryControl },								// 0x98
	{ "Call Waiting Tone", MomentaryControl },							// 0x99
	{ "Confirmation Tone 1", MomentaryControl },						// 0x9A
	{ "Confirmation Tone 2", MomentaryControl },						// 0x9B
	{ "Tones Off", OnOffControl },										// 0x9C
	{ "Outside Ringback", MomentaryControl },							// 0x9D
	{ "Ringer", OnOffControl },											// 0x9E
	{ "(Reserved)", None },												// 0x9F
	{ "(Reserved)", None },												// 0xA0
	{ "(Reserved)", None },												// 0xA1
	{ "(Reserved)", None },												// 0xA2
	{ "(Reserved)", None },												// 0xA3
	{ "(Reserved)", None },												// 0xA4
	{ "(Reserved)", None },												// 0xA5
	{ "(Reserved)", None },												// 0xA6
	{ "(Reserved)", None },												// 0xA7
	{ "(Reserved)", None },												// 0xA8
	{ "(Reserved)", None },												// 0xA9
	{ "(Reserved)", None },												// 0xAA
	{ "(Reserved)", None },												// 0xAB
	{ "(Reserved)", None },												// 0xAC
	{ "(Reserved)", None },												// 0xAD
	{ "(Reserved)", None },												// 0xAE
	{ "(Reserved)", None },												// 0xAF
	{ "Phone Key 0", Selector },										// 0xB0
	{ "Phone Key 1", Selector },										// 0xB1
	{ "Phone Key 2", Selector },										// 0xB2
	{ "Phone Key 3", Selector },										// 0xB3
	{ "Phone Key 4", Selector },										// 0xB4
	{ "Phone Key 5", Selector },										// 0xB5
	{ "Phone Key 6", Selector },										// 0xB6
	{ "Phone Key 7", Selector },										// 0xB7
	{ "Phone Key 8", Selector },										// 0xB8
	{ "Phone Key 9", Selector },										// 0xB9
	{ "Phone Key Star", Selector },										// 0xBA
	{ "Phone Key Pound", Selector },									// 0xBB
	{ "Phone Key A", Selector },										// 0xBC
	{ "Phone Key B", Selector },										// 0xBD
	{ "Phone Key C", Selector },										// 0xBE
	{ "Phone Key D", Selector },										// 0xBF
};

// Consumer Page (0x0C)

static const usageInfo usagePage0C[] = {
	{ "(Unassigned)", None },											// 0x00
// 15.1 Generic Consumer Control Device
	{ "Consumer Control", ApplicationCollection },						// 0x01
	{ "Numeric Key Pad", NamedArray },									// 0x02
// (15.14 Programmable Buttons)
	{ "Programmable Buttons", NamedArray },								// 0x03
	{ "Microphone", ApplicationCollection },							// 0x04
	{ "Headphone", ApplicationCollection },								// 0x05
	{ "Graphic Equalizer", ApplicationCollection },						// 0x06
	{ "(Reserved)", None },												// 0x07
	{ "(Reserved)", None },												// 0x08
	{ "(Reserved)", None },												// 0x09
	{ "(Reserved)", None },												// 0x0A
	{ "(Reserved)", None },												// 0x0B
	{ "(Reserved)", None },												// 0x0C
	{ "(Reserved)", None },												// 0x0D
	{ "(Reserved)", None },												// 0x0E
	{ "(Reserved)", None },												// 0x0F
	{ "(Reserved)", None },												// 0x10
	{ "(Reserved)", None },												// 0x11
	{ "(Reserved)", None },												// 0x12
	{ "(Reserved)", None },												// 0x13
	{ "(Reserved)", None },												// 0x14
	{ "(Reserved)", None },												// 0x15
	{ "(Reserved)", None },												// 0x16
	{ "(Reserved)", None },												// 0x17
	{ "(Reserved)", None },												// 0x18
	{ "(Reserved)", None },												// 0x19
	{ "(Reserved)", None },												// 0x1A
	{ "(Reserved)", None },												// 0x1B
	{ "(Reserved)", None },												// 0x1C
	{ "(Reserved)", None },												// 0x1D
	{ "(Reserved)", None },												// 0x1E
	{ "(Reserved)", None },												// 0x1F
// 15.2 Numeric Key Pad
	{ "+10", OneShotControl },											// 0x20
	{ "+100", OneShotControl },											// 0x21
	{ "AM/PM", OneShotControl },										// 0x22
	{ "(Reserved)", None },												// 0x23
	{ "(Reserved)", None },												// 0x24
	{ "(Reserved)", None },												// 0x25
	{ "(Reserved)", None },												// 0x26
	{ "(Reserved)", None },												// 0x27
	{ "(Reserved)", None },												// 0x28
	{ "(Reserved)", None },												// 0x29
	{ "(Reserved)", None },												// 0x2A
	{ "(Reserved)", None },												// 0x2B
	{ "(Reserved)", None },												// 0x2C
	{ "(Reserved)", None },												// 0x2D
	{ "(Reserved)", None },												// 0x2E
	{ "(Reserved)", None },												// 0x2F
// 15.3 General Controls
	{ "Power", OnOffControl },											// 0x30
	{ "Reset", OneShotControl },										// 0x31
	{ "Sleep", OneShotControl },										// 0x32
	{ "Sleep After", OneShotControl },									// 0x33
	{ "Sleep Mode", RetriggerControl },									// 0x34
	{ "Illumination", OnOffControl },									// 0x35
	{ "Function Buttons", NamedArray },									// 0x36
	{ "(Reserved)", None },												// 0x37
	{ "(Reserved)", None },												// 0x38
	{ "(Reserved)", None },												// 0x39
	{ "(Reserved)", None },												// 0x3A
	{ "(Reserved)", None },												// 0x3B
	{ "(Reserved)", None },												// 0x3C
	{ "(Reserved)", None },												// 0x3D
	{ "(Reserved)", None },												// 0x3E
	{ "(Reserved)", None },												// 0x3F
// 15.4 Menu Controls
	{ "Menu", OnOffControl },											// 0x40
	{ "Menu Pick", OneShotControl },									// 0x41
	{ "Menu Up", OneShotControl },										// 0x42
	{ "Menu Down", OneShotControl },									// 0x43
	{ "Menu Left", OneShotControl },									// 0x44
	{ "Menu Right", OneShotControl },									// 0x45
	{ "Menu Escape", OneShotControl },									// 0x46
	{ "Menu Value Increase", OneShotControl },							// 0x47
	{ "Menu Value Decrease", OneShotControl },							// 0x48
	{ "(Reserved)", None },												// 0x49
	{ "(Reserved)", None },												// 0x4A
	{ "(Reserved)", None },												// 0x4B
	{ "(Reserved)", None },												// 0x4C
	{ "(Reserved)", None },												// 0x4D
	{ "(Reserved)", None },												// 0x4E
	{ "(Reserved)", None },												// 0x4F
	{ "(Reserved)", None },												// 0x50
	{ "(Reserved)", None },												// 0x51
	{ "(Reserved)", None },												// 0x52
	{ "(Reserved)", None },												// 0x53
	{ "(Reserved)", None },												// 0x54
	{ "(Reserved)", None },												// 0x55
	{ "(Reserved)", None },												// 0x56
	{ "(Reserved)", None },												// 0x57
	{ "(Reserved)", None },												// 0x58
	{ "(Reserved)", None },												// 0x59
	{ "(Reserved)", None },												// 0x5A
	{ "(Reserved)", None },												// 0x5B
	{ "(Reserved)", None },												// 0x5C
	{ "(Reserved)", None },												// 0x5D
	{ "(Reserved)", None },												// 0x5E
	{ "(Reserved)", None },												// 0x5F
// 15.5 Display Controls
	{ "Data On Screen", OnOffControl },									// 0x60
	{ "Closed Caption", OnOffControl },									// 0x61
	{ "Closed Caption Select", OneShotControl },						// 0x62
	{ "VCR/TV", OnOffControl },											// 0x63
	{ "Broadcast Mode", OneShotControl },								// 0x64
	{ "Snapshot", OneShotControl },										// 0x65
	{ "Still", OneShotControl },										// 0x66
	{ "(Reserved)", None },												// 0x67
	{ "(Reserved)", None },												// 0x68
	{ "(Reserved)", None },												// 0x69
	{ "(Reserved)", None },												// 0x6A
	{ "(Reserved)", None },												// 0x6B
	{ "(Reserved)", None },												// 0x6C
	{ "(Reserved)", None },												// 0x6D
	{ "(Reserved)", None },												// 0x6E
	{ "(Reserved)", None },												// 0x6F
	{ "(Reserved)", None },												// 0x70
	{ "(Reserved)", None },												// 0x71
	{ "(Reserved)", None },												// 0x72
	{ "(Reserved)", None },												// 0x73
	{ "(Reserved)", None },												// 0x74
	{ "(Reserved)", None },												// 0x75
	{ "(Reserved)", None },												// 0x76
	{ "(Reserved)", None },												// 0x77
	{ "(Reserved)", None },												// 0x78
	{ "(Reserved)", None },												// 0x79
	{ "(Reserved)", None },												// 0x7A
	{ "(Reserved)", None },												// 0x7B
	{ "(Reserved)", None },												// 0x7C
	{ "(Reserved)", None },												// 0x7D
	{ "(Reserved)", None },												// 0x7E
	{ "(Reserved)", None },												// 0x7F
// 15.6 Selection Controls
	{ "Selection", NamedArray },										// 0x80
	{ "Assign Selection", OneShotControl },								// 0x81
	{ "Mode Step", OneShotControl },									// 0x82
	{ "Recall Last", OneShotControl },									// 0x83
	{ "Enter Channel", OneShotControl },								// 0x84
	{ "Order Movie", OneShotControl },									// 0x85
	{ "Channel", LinearControl },										// 0x86
	{ "Media Selection", NamedArray },									// 0x87
	{ "Media Select Computer", Selector },								// 0x88
	{ "Media Select TV", Selector },									// 0x89
	{ "Media Select WWW", Selector },									// 0x8A
	{ "Media Select DVD", Selector },									// 0x8B
	{ "Media Select Telephone", Selector },								// 0x8C
	{ "Media Select Program Guide", Selector },							// 0x8D
	{ "Media Select Video Phone", Selector },							// 0x8E
	{ "Media Select Games", Selector },									// 0x8F
	{ "Media Select Messages", Selector },								// 0x90
	{ "Media Select CD", Selector },									// 0x91
	{ "Media Select VCR", Selector },									// 0x92
	{ "Media Select Tuner", Selector },									// 0x93
	{ "Quit", OneShotControl },											// 0x94
	{ "Help", OnOffControl },											// 0x95
	{ "Media Select Tape", Selector },									// 0x96
	{ "Media Select Cable", Selector },									// 0x97
	{ "Media Select Satellite", Selector },								// 0x98
	{ "Media Select Security", Selector },								// 0x99
	{ "Media Select Home", Selector },									// 0x9A
	{ "Media Select Call", Selector },									// 0x9B
	{ "Channel Increment", OneShotControl },							// 0x9C
	{ "Channel Decrement", OneShotControl },							// 0x9D
	{ "Media Select SAP", Selector },									// 0x9E
	{ "(Reserved)", None },												// 0x9F
	{ "VCR Plus", OneShotControl },										// 0xA0
	{ "Once", OneShotControl },											// 0xA1
	{ "Daily", OneShotControl },										// 0xA2
	{ "Weekly", OneShotControl },										// 0xA3
	{ "Monthly", OneShotControl },										// 0xA4
	{ "(Reserved)", None },												// 0xA5
	{ "(Reserved)", None },												// 0xA6
	{ "(Reserved)", None },												// 0xA7
	{ "(Reserved)", None },												// 0xA8
	{ "(Reserved)", None },												// 0xA9
	{ "(Reserved)", None },												// 0xAA
	{ "(Reserved)", None },												// 0xAB
	{ "(Reserved)", None },												// 0xAC
	{ "(Reserved)", None },												// 0xAD
	{ "(Reserved)", None },												// 0xAE
	{ "(Reserved)", None },												// 0xAF
// 15.7 Transport Controls
	{ "Play", OnOffControl },											// 0xB0
	{ "Pause", OnOffControl },											// 0xB1
	{ "Record", OnOffControl },											// 0xB2
	{ "Fast Forward", OnOffControl },									// 0xB3
	{ "Rewind", OnOffControl },											// 0xB4
	{ "Scan Next Track", OneShotControl },								// 0xB5
	{ "Scan Previous Track", OneShotControl },							// 0xB6
	{ "Stop", OneShotControl },											// 0xB7
	{ "Eject", OneShotControl },										// 0xB8
	{ "Random Play", OnOffControl },									// 0xB9
	{ "Select Disc", NamedArray },										// 0xBA
	{ "Enter Disc", MomentaryControl },									// 0xBB
	{ "Repeat", OneShotControl },										// 0xBC
	{ "Tracking", LinearControl },										// 0xBD
	{ "Track Normal", OneShotControl },									// 0xBE
	{ "Slow Tracking", LinearControl },									// 0xBF
	{ "Frame Forward", RetriggerControl },								// 0xC0
	{ "Frame Back", RetriggerControl },									// 0xC1
// 15.8 Seach Controls
	{ "Mark", OneShotControl },											// 0xC2
	{ "Clear Mark", OneShotControl },									// 0xC3
	{ "Repeat From Mark", OneShotControl },								// 0xC4
	{ "Return To Mark", OneShotControl },								// 0xC5
	{ "Search Mark Forward", OneShotControl },							// 0xC6
	{ "Search Mark Backwards", OneShotControl },						// 0xC7
	{ "Counter Reset", OneShotControl },								// 0xC8
	{ "Show Counter", OneShotControl },									// 0xC9
	{ "Tracking Increment", RetriggerControl },							// 0xCA
	{ "Tracking Decrement", RetriggerControl },							// 0xCB
	{ "Stop/Eject", OneShotControl },									// 0xCC
	{ "Play/Pause", OneShotControl },									// 0xCD
	{ "Play/Skip", OneShotControl },									// 0xCE
	{ "(Reserved)", None },												// 0xCF
	{ "(Reserved)", None },												// 0xD0
	{ "(Reserved)", None },												// 0xD1
	{ "(Reserved)", None },												// 0xD2
	{ "(Reserved)", None },												// 0xD3
	{ "(Reserved)", None },												// 0xD4
	{ "(Reserved)", None },												// 0xD5
	{ "(Reserved)", None },												// 0xD6
	{ "(Reserved)", None },												// 0xD7
	{ "(Reserved)", None },												// 0xD8
	{ "(Reserved)", None },												// 0xD9
	{ "(Reserved)", None },												// 0xDA
	{ "(Reserved)", None },												// 0xDB
	{ "(Reserved)", None },												// 0xDC
	{ "(Reserved)", None },												// 0xDD
	{ "(Reserved)", None },												// 0xDE
	{ "(Reserved)", None },												// 0xDF	
// 15.9 Audio Controls
	{ "Volume", LinearControl },										// 0xE0
	{ "Balance", LinearControl },										// 0xE1
	{ "Mute", OnOffControl },											// 0xE2
	{ "Bass", LinearControl },											// 0xE3
	{ "Treble", LinearControl },										// 0xE4
	{ "Bass Boost", OnOffControl },										// 0xE5
	{ "Surround Mode", OneShotControl },								// 0xE6
	{ "Loudness", OnOffControl },										// 0xE7
	{ "MPX", OnOffControl },											// 0xE8
	{ "Volume Increment", RetriggerControl },							// 0xE9
	{ "Volume Decrement", RetriggerControl },							// 0xEA
	{ "(Reserved)", None },												// 0xEB
	{ "(Reserved)", None },												// 0xEC
	{ "(Reserved)", None },												// 0xED
	{ "(Reserved)", None },												// 0xEE
	{ "(Reserved)", None },												// 0xEF	
// 15.10 Speed Controls
	{ "Speed Select", OneShotControl },									// 0xF0
	{ "Playback Speed", NamedArray },									// 0xF1
	{ "Standard Play", Selector },										// 0xF2
	{ "Long Play", Selector },											// 0xF3
	{ "Extended Play", Selector },										// 0xF4
	{ "Slow", OneShotControl },											// 0xF5
	{ "(Reserved)", None },												// 0xF6
	{ "(Reserved)", None },												// 0xF7
	{ "(Reserved)", None },												// 0xF8
	{ "(Reserved)", None },												// 0xF9
	{ "(Reserved)", None },												// 0xFA
	{ "(Reserved)", None },												// 0xFB
	{ "(Reserved)", None },												// 0xFC
	{ "(Reserved)", None },												// 0xFD
	{ "(Reserved)", None },												// 0xFE
	{ "(Reserved)", None },												// 0xFF	
// 15.11 Home and Security Controls
	{ "Fan Enable", OnOffControl },										// 0x100
	{ "Fan Speed", LinearControl },										// 0x101
	{ "Light Enable", OnOffControl },									// 0x102
	{ "Light Illumination Level", LinearControl },						// 0x103
	{ "Climate Control Enable", OnOffControl },							// 0x104
	{ "Room Temperature", LinearControl },								// 0x105
	{ "Security Enable", OnOffControl },								// 0x106
	{ "Fire Alarm", OneShotControl },									// 0x107
	{ "Police Alarm", OneShotControl },									// 0x108
	{ "Proximity", LinearControl },										// 0x109
	{ "Motion", OneShotControl },										// 0x10A
	{ "Duress Alarm", OneShotControl },									// 0x10B
	{ "Holdup Alarm", OneShotControl },									// 0x10C
	{ "Medical Alarm", OneShotControl },								// 0x10D
	{ "(Reserved)", None },												// 0x10E
	{ "(Reserved)", None },												// 0x10F
	{ "(Reserved)", None },												// 0x110
	{ "(Reserved)", None },												// 0x111
	{ "(Reserved)", None },												// 0x112
	{ "(Reserved)", None },												// 0x113
	{ "(Reserved)", None },												// 0x114
	{ "(Reserved)", None },												// 0x115
	{ "(Reserved)", None },												// 0x116
	{ "(Reserved)", None },												// 0x117
	{ "(Reserved)", None },												// 0x118
	{ "(Reserved)", None },												// 0x119
	{ "(Reserved)", None },												// 0x11A
	{ "(Reserved)", None },												// 0x11B
	{ "(Reserved)", None },												// 0x11C
	{ "(Reserved)", None },												// 0x11D
	{ "(Reserved)", None },												// 0x11E
	{ "(Reserved)", None },												// 0x11F
	{ "(Reserved)", None },												// 0x120
	{ "(Reserved)", None },												// 0x121
	{ "(Reserved)", None },												// 0x122
	{ "(Reserved)", None },												// 0x123
	{ "(Reserved)", None },												// 0x124
	{ "(Reserved)", None },												// 0x125
	{ "(Reserved)", None },												// 0x126
	{ "(Reserved)", None },												// 0x127
	{ "(Reserved)", None },												// 0x128
	{ "(Reserved)", None },												// 0x129
	{ "(Reserved)", None },												// 0x12A
	{ "(Reserved)", None },												// 0x12B
	{ "(Reserved)", None },												// 0x12C
	{ "(Reserved)", None },												// 0x12D
	{ "(Reserved)", None },												// 0x12E
	{ "(Reserved)", None },												// 0x12F
	{ "(Reserved)", None },												// 0x130
	{ "(Reserved)", None },												// 0x131
	{ "(Reserved)", None },												// 0x132
	{ "(Reserved)", None },												// 0x133
	{ "(Reserved)", None },												// 0x134
	{ "(Reserved)", None },												// 0x135
	{ "(Reserved)", None },												// 0x136
	{ "(Reserved)", None },												// 0x137
	{ "(Reserved)", None },												// 0x138
	{ "(Reserved)", None },												// 0x139
	{ "(Reserved)", None },												// 0x13A
	{ "(Reserved)", None },												// 0x13B
	{ "(Reserved)", None },												// 0x13C
	{ "(Reserved)", None },												// 0x13D
	{ "(Reserved)", None },												// 0x13E
	{ "(Reserved)", None },												// 0x13F
	{ "(Reserved)", None },												// 0x140
	{ "(Reserved)", None },												// 0x141
	{ "(Reserved)", None },												// 0x142
	{ "(Reserved)", None },												// 0x143
	{ "(Reserved)", None },												// 0x144
	{ "(Reserved)", None },												// 0x145
	{ "(Reserved)", None },												// 0x146
	{ "(Reserved)", None },												// 0x147
	{ "(Reserved)", None },												// 0x148
	{ "(Reserved)", None },												// 0x149
	{ "(Reserved)", None },												// 0x14A
	{ "(Reserved)", None },												// 0x14B
	{ "(Reserved)", None },												// 0x14C
	{ "(Reserved)", None },												// 0x14D
	{ "(Reserved)", None },												// 0x14E
	{ "(Reserved)", None },												// 0x14F
	{ "Balance Right", RetriggerControl },								// 0x150
	{ "Balance Left", RetriggerControl },								// 0x151
	{ "Bass Increment", RetriggerControl },								// 0x152
	{ "Bass Decrement", RetriggerControl },								// 0x153
	{ "Treble Increment", RetriggerControl },							// 0x154
	{ "Treble Decrement", RetriggerControl },							// 0x155
	{ "(Reserved)", None },												// 0x156
	{ "(Reserved)", None },												// 0x157
	{ "(Reserved)", None },												// 0x158
	{ "(Reserved)", None },												// 0x159
	{ "(Reserved)", None },												// 0x15A
	{ "(Reserved)", None },												// 0x15B
	{ "(Reserved)", None },												// 0x15C
	{ "(Reserved)", None },												// 0x15D
	{ "(Reserved)", None },												// 0x15E
	{ "(Reserved)", None },												// 0x15F
// 15.12
	{ "Speaker System", LogicalCollection },							// 0x160
	{ "Channel Left", LogicalCollection },								// 0x161
	{ "Channel Right", LogicalCollection },								// 0x162
	{ "Channel Center", LogicalCollection },							// 0x163
	{ "Channel Front", LogicalCollection },								// 0x164
	{ "Channel Center Front", LogicalCollection },						// 0x165
	{ "Channel Side", LogicalCollection },								// 0x166
	{ "Channel Surround", LogicalCollection },							// 0x167
	{ "Channel Low Frequency Enhancement", LogicalCollection },			// 0x168
	{ "Channel Top", LogicalCollection },								// 0x169
	{ "Channel Unknown", LogicalCollection },							// 0x16A
	{ "(Reserved)", None },												// 0x16B
	{ "(Reserved)", None },												// 0x16C
	{ "(Reserved)", None },												// 0x16D
	{ "(Reserved)", None },												// 0x16E
	{ "(Reserved)", None },												// 0x16F
// 15.13
	{ "Sub-channel", LinearControl },									// 0x170
	{ "Sub-channel Increment", OneShotControl },						// 0x171
	{ "Sub-channel Decrement", OneShotControl },						// 0x172
	{ "Alternate Audio Increment", OneShotControl },					// 0x173
	{ "Alternate Audio Decrement", OneShotControl },					// 0x174
	{ "(Reserved)", None },												// 0x175
	{ "(Reserved)", None },												// 0x176
	{ "(Reserved)", None },												// 0x177
	{ "(Reserved)", None },												// 0x178
	{ "(Reserved)", None },												// 0x179
	{ "(Reserved)", None },												// 0x17A
	{ "(Reserved)", None },												// 0x17B
	{ "(Reserved)", None },												// 0x17C
	{ "(Reserved)", None },												// 0x17D
	{ "(Reserved)", None },												// 0x17E
	{ "(Reserved)", None },												// 0x17F
	{ "Application Launch Buttons", NamedArray },						// 0x180
	{ "AL Launch Button Configuration Tool", Selector },				// 0x181
	{ "AL Programmable Button Configuration", Selector },				// 0x182
	{ "AL Consumer Control Configuration", Selector },					// 0x183
	{ "AL Word Processor", Selector },									// 0x184
	{ "AL Text Editor", Selector },										// 0x185
	{ "AL Spreadsheet", Selector },										// 0x186
	{ "AL Graphics Editor", Selector },									// 0x187
	{ "AL Presentation App", Selector },								// 0x188
	{ "AL Database App", Selector },									// 0x189
	{ "AL Email Reader", Selector },									// 0x18A
	{ "AL Newsreader", Selector },										// 0x18B
	{ "AL Voicemail", Selector },										// 0x18C
	{ "AL Contacts/Address Book", Selector },							// 0x18D
	{ "AL Calendar/Schedule", Selector },								// 0x18E
	{ "AL Task/Project Manager", Selector },							// 0x18F
	{ "AL Log/Journal/Timecard", Selector },							// 0x190
	{ "AL Checkbook/Finance", Selector },								// 0x191
	{ "AL Calculator", Selector },										// 0x192
	{ "AL A/V Capture/Playback", Selector },							// 0x193
	{ "AL Local Machine Browser", Selector },							// 0x194
	{ "AL LAN/WAN Browser", Selector },									// 0x195
	{ "AL Internet Browser", Selector },								// 0x196
	{ "AL Remote Networking/ISP Connect", Selector },					// 0x197
	{ "AL Network Conference", Selector },								// 0x198
	{ "AL Network Chat", Selector },									// 0x199
	{ "AL Telephony/Dialer", Selector },								// 0x19A
	{ "AL Logon", Selector },											// 0x19B
	{ "AL Logoff", Selector },											// 0x19C
	{ "AL Logon/Logoff", Selector },									// 0x19D
	{ "AL Terminal Lock/Screensaver", Selector },						// 0x19E
	{ "AL Control Panel", Selector },									// 0x19F
	{ "AL Command Line Processor/Run", Selector },						// 0x1A0
	{ "AL Process/Task Manager", Selector },							// 0x1A1
	{ "AL Select Task/Application", Selector },							// 0x1A2
	{ "AL Next Task/Application", Selector },							// 0x1A3
	{ "AL Previous Task/Application", Selector },						// 0x1A4
	{ "AL Preemptive Halt Task/Application", Selector },				// 0x1A5
	{ "AL Integrated Help Center", Selector },							// 0x1A6
	{ "AL Documents", Selector },										// 0x1A7
	{ "AL Thesaurus", Selector },										// 0x1A8
	{ "AL Dictionary", Selector },										// 0x1A9
	{ "AL Desktop", Selector },											// 0x1AA
	{ "AL Spell Check", Selector },										// 0x1AB
	{ "AL Grammar Check", Selector },									// 0x1AC
	{ "AL Wireless Status", Selector },									// 0x1AD
	{ "AL Keyboard Layout", Selector },									// 0x1AE
	{ "AL Virus Protection", Selector },								// 0x1AF
	{ "AL Encryption", Selector },										// 0x1B0
	{ "AL Screen Saver", Selector },									// 0x1B1
	{ "AL Alarms", Selector },											// 0x1B2
	{ "AL Clock", Selector },											// 0x1B3
	{ "AL File Browser", Selector },									// 0x1B4
	{ "AL Power Status", Selector },									// 0x1B5
	{ "AL Image Browser", Selector },									// 0x1B6
	{ "AL Audio Browser", Selector },									// 0x1B7
	{ "AL Movie Browser", Selector },									// 0x1B8
	{ "AL Digital Rights Manager", Selector },							// 0x1B9
	{ "AL Digital Wallet", Selector },									// 0x1BA
	{ "(Reserved)", None },												// 0x1BB
	{ "AL Instant Messaging", Selector },								// 0x1BC
	{ "AL OEM Features/Tips/Tutorial Browser", Selector },				// 0x1BD
	{ "AL OEM Help", Selector },										// 0x1BE
	{ "AL Online Community", Selector },								// 0x1BF
	{ "AL Entertainment Content Browser", Selector },					// 0x1C0
	{ "AL Online Shopping Browser", Selector },							// 0x1C1
	{ "AL SmartCard Information/Help", Selector },						// 0x1C2
	{ "AL Market Monitor/Finance Browser", Selector },					// 0x1C3
	{ "AL Customized Corporate News Browser", Selector },				// 0x1C4
	{ "AL Online Activity Browser", Selector },							// 0x1C5
	{ "AL Research/Seach Browser", Selector },							// 0x1C6
	{ "AL Audio Player", Selector },									// 0x1C7
	{ "(Reserved)", None },												// 0x1C8
	{ "(Reserved)", None },												// 0x1C9
	{ "(Reserved)", None },												// 0x1CA
	{ "(Reserved)", None },												// 0x1CB
	{ "(Reserved)", None },												// 0x1CC
	{ "(Reserved)", None },												// 0x1CD
	{ "(Reserved)", None },												// 0x1CE
	{ "(Reserved)", None },												// 0x1CF
	{ "(Reserved)", None },												// 0x1D0
	{ "(Reserved)", None },												// 0x1D1
	{ "(Reserved)", None },												// 0x1D2
	{ "(Reserved)", None },												// 0x1D3
	{ "(Reserved)", None },												// 0x1D4
	{ "(Reserved)", None },												// 0x1D5
	{ "(Reserved)", None },												// 0x1D6
	{ "(Reserved)", None },												// 0x1D7
	{ "(Reserved)", None },												// 0x1D8
	{ "(Reserved)", None },												// 0x1D9
	{ "(Reserved)", None },												// 0x1DA
	{ "(Reserved)", None },												// 0x1DB
	{ "(Reserved)", None },												// 0x1DC
	{ "(Reserved)", None },												// 0x1DD
	{ "(Reserved)", None },												// 0x1DE
	{ "(Reserved)", None },												// 0x1DF
	{ "(Reserved)", None },												// 0x1E0
	{ "(Reserved)", None },												// 0x1E1
	{ "(Reserved)", None },												// 0x1E2
	{ "(Reserved)", None },												// 0x1E3
	{ "(Reserved)", None },												// 0x1E4
	{ "(Reserved)", None },												// 0x1E5
	{ "(Reserved)", None },												// 0x1E6
	{ "(Reserved)", None },												// 0x1E7
	{ "(Reserved)", None },												// 0x1E8
	{ "(Reserved)", None },												// 0x1E9
	{ "(Reserved)", None },												// 0x1EA
	{ "(Reserved)", None },												// 0x1EB
	{ "(Reserved)", None },												// 0x1EC
	{ "(Reserved)", None },												// 0x1ED
	{ "(Reserved)", None },												// 0x1EE
	{ "(Reserved)", None },												// 0x1EF
	{ "(Reserved)", None },												// 0x1F0
	{ "(Reserved)", None },												// 0x1F1
	{ "(Reserved)", None },												// 0x1F2
	{ "(Reserved)", None },												// 0x1F3
	{ "(Reserved)", None },												// 0x1F4
	{ "(Reserved)", None },												// 0x1F5
	{ "(Reserved)", None },												// 0x1F6
	{ "(Reserved)", None },												// 0x1F7
	{ "(Reserved)", None },												// 0x1F8
	{ "(Reserved)", None },												// 0x1F9
	{ "(Reserved)", None },												// 0x1FA
	{ "(Reserved)", None },												// 0x1FB
	{ "(Reserved)", None },												// 0x1FC
	{ "(Reserved)", None },												// 0x1FD
	{ "(Reserved)", None },												// 0x1FE
	{ "(Reserved)", None },												// 0x1FF
// 15.16 Generic GUI Application Controls
	{ "Generic GUI Application Controls", NamedArray },					// 0x200
	{ "AC New",	Selector },												// 0x201
	{ "AC Open", Selector },											// 0x202
	{ "AC Close", Selector },											// 0x203
	{ "AC Exit", Selector },											// 0x204
	{ "AC Maximize", Selector },										// 0x205
	{ "AC Minimize", Selector },										// 0x206
	{ "AC Save", Selector },											// 0x207
	{ "AC Print", Selector },											// 0x208
	{ "AC Properties", Selector },										// 0x209
	// This weird hole looked like a typo in the HID usage table
	// I verified with MSDN documentation that is really is here
	// I guess they made a typo in the original documentation and nobody
	// caught it, so they had to leave it!
	{ "(Reserved)", None },												// 0x20A
	{ "(Reserved)", None },												// 0x20B
	{ "(Reserved)", None },												// 0x20C
	{ "(Reserved)", None },												// 0x20D
	{ "(Reserved)", None },												// 0x20E
	{ "(Reserved)", None },												// 0x20F
	{ "(Reserved)", None },												// 0x210
	{ "(Reserved)", None },												// 0x211
	{ "(Reserved)", None },												// 0x212
	{ "(Reserved)", None },												// 0x213
	{ "(Reserved)", None },												// 0x214
	{ "(Reserved)", None },												// 0x215
	{ "(Reserved)", None },												// 0x216
	{ "(Reserved)", None },												// 0x217
	{ "(Reserved)", None },												// 0x218
	{ "(Reserved)", None },												// 0x219
	{ "AC Undo", Selector },											// 0x21A
	{ "AC Copy", Selector },											// 0x21B
	{ "AC Cut", Selector },												// 0x21C
	{ "AC Paste", Selector },											// 0x21D
	{ "AC Select All", Selector },										// 0x21E
	{ "AC Find", Selector },											// 0x21F
	{ "AC Find and Replace", Selector },								// 0x220
	{ "AC Seach", Selector },											// 0x221
	{ "AC Go To", Selector },											// 0x222
	{ "AC Home", Selector },											// 0x223
	{ "AC Back", Selector },											// 0x224
	{ "AC Forward", Selector },											// 0x225
	{ "AC Stop", Selector },											// 0x226
	{ "AC Refresh", Selector },											// 0x227
	{ "AC Previous Link", Selector },									// 0x228
	{ "AC Next Link", Selector },										// 0x229
	{ "AC Bookmarks", Selector },										// 0x22A
	{ "AC History", Selector },											// 0x22B
	{ "AC Subscriptions", Selector },									// 0x22C
	{ "AC Zoom In", Selector },											// 0x22D
	{ "AC Zoom Out", Selector },										// 0x22E
	{ "AC Zoom", LinearControl },										// 0x22F
	{ "AC Full Screen View", Selector },								// 0x230
	{ "AC Normal View", Selector },										// 0x231
	{ "AC View Toggle", Selector },										// 0x232
	{ "AC Scroll Up", Selector },										// 0x233
	{ "AC Scroll Down", Selector },										// 0x234
	{ "AC Scroll", LinearControl },										// 0x235
	{ "AC Pan Left", Selector },										// 0x236
	{ "AC Pan Right", Selector },										// 0x237
	{ "AC Pan", LinearControl },										// 0x238
	{ "AC New Window", Selector },										// 0x239
	{ "AC Tile Horizontally", Selector },								// 0x23A
	{ "AC Tile Vertically", Selector },									// 0x23B
	{ "AC Format", Selector },											// 0x23C
	{ "AC Edit", Selector },											// 0x23D
	{ "AC Bold", Selector },											// 0x23E
	{ "AC Italics", Selector },											// 0x23F
	{ "AC Underline", Selector },										// 0x240
	{ "AC Strikethrough", Selector },									// 0x241
	{ "AC Subscript", Selector },										// 0x242
	{ "AC Superscript", Selector },										// 0x243
	{ "AC All Caps", Selector },										// 0x244
	{ "AC Rotate", Selector },											// 0x245
	{ "AC Resize", Selector },											// 0x246
	{ "AC Flip Horizontal", Selector },									// 0x247
	{ "AC Flip Vertical", Selector },									// 0x248
	{ "AC Mirror Horizontal", Selector },								// 0x249
	{ "AC Mirror Vertical", Selector },									// 0x24A
	{ "AC Font Select", Selector },										// 0x24B
	{ "AC Font Color", Selector },										// 0x24C
	{ "AC Font Size", Selector },										// 0x24D
	{ "AC Justify Left", Selector },									// 0x24E
	{ "AC Justify Center H", Selector },								// 0x24F
	{ "AC Justify Right", Selector },									// 0x250
	{ "AC Justify Block H", Selector },									// 0x251
	{ "AC Justify Top", Selector },										// 0x252
	{ "AC Justify Center V", Selector },								// 0x253
	{ "AC Justify Bottom", Selector },									// 0x254
	{ "AC Justify Block V", Selector },									// 0x255
	{ "AC Indent Decrease", Selector },									// 0x256
	{ "AC Indent Increase", Selector },									// 0x257
	{ "AC Numbered List", Selector },									// 0x258
	{ "AC Restart Numbering", Selector },								// 0x259
	{ "AC Bulleted List", Selector },									// 0x25A
	{ "AC Promote", Selector },											// 0x25B
	{ "AC Demote", Selector },											// 0x25C
	{ "AC Yes", Selector },												// 0x25D
	{ "AC No", Selector },												// 0x25E
	{ "AC Cancel", Selector },											// 0x25F
	{ "AC Catalog", Selector },											// 0x260
	{ "AC Buy/Checkout", Selector },									// 0x261
	{ "AC Add to Cart", Selector },										// 0x262
	{ "AC Expand", Selector },											// 0x263
	{ "AC Expand All", Selector },										// 0x264
	{ "AC Collapse", Selector },										// 0x265
	{ "AC Collapse All", Selector },									// 0x266
	{ "AC Print Preview", Selector },									// 0x267
	{ "AC Paste Special", Selector },									// 0x268
	{ "AC Insert Mode", Selector },										// 0x269
	{ "AC Delete", Selector },											// 0x26A
	{ "AC Lock", Selector },											// 0x26B
	{ "AC Unlock", Selector },											// 0x26C
	{ "AC Protect", Selector },											// 0x26D
	{ "AC Unprotect", Selector },										// 0x26E
	{ "AC Attach Comment", Selector },									// 0x26F
	{ "AC Delete Comment", Selector },									// 0x270
	{ "AC View Comment", Selector },									// 0x271
	{ "AC Select Word", Selector },										// 0x272
	{ "AC Select Sentence", Selector },									// 0x273
	{ "AC Select Paragraph", Selector },								// 0x274
	{ "AC Select Column", Selector },									// 0x275
	{ "AC Select Row", Selector },										// 0x276
	{ "AC Select Table", Selector },									// 0x277
	{ "AC Select Object", Selector },									// 0x278
	{ "AC Redo/Repeat", Selector },										// 0x279
	{ "AC Sort", Selector },											// 0x27A
	{ "AC Sort Ascending", Selector },									// 0x27B
	{ "AC Sort Descending", Selector },									// 0x27C
	{ "AC Filter", Selector },											// 0x27D
	{ "AC Set Clock", Selector },										// 0x27E
	{ "AC View Clock", Selector },										// 0x27F
	{ "AC Select Time Zone", Selector },								// 0x280
	{ "AC Edit Time Zones", Selector },									// 0x281
	{ "AC Set Alarm", Selector },										// 0x282
	{ "AC Clear Alarm", Selector },										// 0x283
	{ "AC Snooze Alarm", Selector },									// 0x284
	{ "AC Reset Alarm", Selector },										// 0x285
	{ "AC Synchronize", Selector },										// 0x286
	{ "AC Send/Receive", Selector },									// 0x287
	{ "AC Send To", Selector },											// 0x288
	{ "AC Reply", Selector },											// 0x289
	{ "AC Reply All", Selector },										// 0x28A
	{ "AC Forward Msg", Selector },										// 0x28B
	{ "AC Send", Selector },											// 0x28C
	{ "AC Attach File", Selector },										// 0x28D
	{ "AC Upload", Selector },											// 0x28E
	{ "AC Download (Save Target As)", Selector },						// 0x28F
	{ "AC Set Borders", Selector },										// 0x290
	{ "AC Insert Row", Selector },										// 0x291
	{ "AC Insert Column", Selector },									// 0x292
	{ "AC Insert File", Selector },										// 0x293
	{ "AC Insert Picture", Selector },									// 0x294
	{ "AC Insert Object", Selector },									// 0x295
	{ "AC Insert Symbol", Selector },									// 0x296
	{ "AC Save and Close", Selector },									// 0x297
	{ "AC Rename", Selector },											// 0x298
	{ "AC Merge", Selector },											// 0x299
	{ "AC Split", Selector },											// 0x29A
	{ "AC Distribute Horizontally", Selector },							// 0x29B
	{ "AC Distribute Vertically", Selector },							// 0x29C	
};

// Usage Page 0x0D - Digitizers
static const usageInfo usagePage0D[] = {
	{ "(Undefined)", None },											// 0x00
// 16.1 Digitizer Devices
	{ "Digitizer", ApplicationCollection },								// 0x01
	{ "Pen", ApplicationCollection },									// 0x02
	{ "Light Pen", ApplicationCollection },								// 0x03
	{ "Touch Screen", ApplicationCollection },							// 0x04
	{ "Touch Pad", ApplicationCollection },								// 0x05
	{ "White Board", ApplicationCollection },							// 0x06
	{ "Coordinate Measuring Machine", ApplicationCollection },			// 0x07
	{ "3D Digitizer", ApplicationCollection },							// 0x08
	{ "Stereo Plotter", ApplicationCollection },						// 0x09
	{ "Articulated Arm", ApplicationCollection },						// 0x0A
	{ "Armature", ApplicationCollection },								// 0x0B
	{ "Multiple Point Digitizer", ApplicationCollection },				// 0x0C
	{ "Free Space Wand", ApplicationCollection },						// 0x0D
	{ "(Reserved)", None },												// 0x0E
	{ "(Reserved)", None },												// 0x0F
	{ "(Reserved)", None },												// 0x10
	{ "(Reserved)", None },												// 0x11
	{ "(Reserved)", None },												// 0x12
	{ "(Reserved)", None },												// 0x13
	{ "(Reserved)", None },												// 0x14
	{ "(Reserved)", None },												// 0x15
	{ "(Reserved)", None },												// 0x16
	{ "(Reserved)", None },												// 0x17
	{ "(Reserved)", None },												// 0x18
	{ "(Reserved)", None },												// 0x19
	{ "(Reserved)", None },												// 0x1A
	{ "(Reserved)", None },												// 0x1B
	{ "(Reserved)", None },												// 0x1C
	{ "(Reserved)", None },												// 0x1D
	{ "(Reserved)", None },												// 0x1E
	{ "(Reserved)", None },												// 0x1F
// 16.2 Digitizer Transducer Collection Usages
	{ "Stylus", LogicalCollection },									// 0x20
	{ "Puck", LogicalCollection },										// 0x21
	{ "Finger", LogicalCollection },									// 0x22
	{ "(Reserved)", None },												// 0x23
	{ "(Reserved)", None },												// 0x24
	{ "(Reserved)", None },												// 0x25
	{ "(Reserved)", None },												// 0x26
	{ "(Reserved)", None },												// 0x27
	{ "(Reserved)", None },												// 0x28
	{ "(Reserved)", None },												// 0x29
	{ "(Reserved)", None },												// 0x2A
	{ "(Reserved)", None },												// 0x2B
	{ "(Reserved)", None },												// 0x2C
	{ "(Reserved)", None },												// 0x2D
	{ "(Reserved)", None },												// 0x2E
	{ "(Reserved)", None },												// 0x2F
// 16.3 Digitizer Report Field Usages
	{ "Tip Pressure", DynamicValue },									// 0x30
	{ "Barrel Pressure", DynamicValue },								// 0x31
	{ "In Range", MomentaryControl },									// 0x32
	{ "Touch", MomentaryControl },										// 0x33
	{ "Untouch", OneShotControl },										// 0x34
	{ "Tap", OneShotControl },											// 0x35
	{ "Quality", DynamicValue },										// 0x36
	{ "Data Valid", MomentaryControl },									// 0x37
	{ "Transducer Index", DynamicValue },								// 0x38
	{ "Tablet Function Keys", LogicalCollection },						// 0x39
	{ "Program Change Keys", LogicalCollection },						// 0x3A
	{ "Battery Strength", DynamicValue },								// 0x3B
	{ "Invert", MomentaryControl },										// 0x3C
	{ "X Tilt", DynamicValue },											// 0x3D
	{ "Y Tilt", DynamicValue },											// 0x3E
	{ "Azimuth", DynamicValue },										// 0x3F
	{ "Altitude", DynamicValue },										// 0x40
	{ "Twist", DynamicValue },											// 0x41
// 16.4 Digitizer Switch Usages
	{ "Tip Switch", MomentaryControl },									// 0x42
	{ "Secondary Tip Switch", MomentaryControl },						// 0x43
	{ "Barrel Switch", MomentaryControl },								// 0x44
	{ "Eraser", MomentaryControl },										// 0x45
	{ "Tablet Pick", MomentaryControl },								// 0x46
};
	
// Usage Page 0x14 - Alphanumeric Display Page
static const usageInfo usagePage14[] = {
	{ "(Undefined", None },												// 0x00
	{ "Alphanumeric Display", ApplicationCollection },					// 0x01
	{ "Bitmapped Display", ApplicationCollection },						// 0x02
	{ "(Reserved)", None },												// 0x03
	{ "(Reserved)", None },												// 0x04
	{ "(Reserved)", None },												// 0x05
	{ "(Reserved)", None },												// 0x06
	{ "(Reserved)", None },												// 0x07
	{ "(Reserved)", None },												// 0x08
	{ "(Reserved)", None },												// 0x09
	{ "(Reserved)", None },												// 0x0A
	{ "(Reserved)", None },												// 0x0B
	{ "(Reserved)", None },												// 0x0C
	{ "(Reserved)", None },												// 0x0D
	{ "(Reserved)", None },												// 0x0E
	{ "(Reserved)", None },												// 0x0F
	{ "(Reserved)", None },												// 0x10
	{ "(Reserved)", None },												// 0x11
	{ "(Reserved)", None },												// 0x12
	{ "(Reserved)", None },												// 0x13
	{ "(Reserved)", None },												// 0x14
	{ "(Reserved)", None },												// 0x15
	{ "(Reserved)", None },												// 0x16
	{ "(Reserved)", None },												// 0x17
	{ "(Reserved)", None },												// 0x18
	{ "(Reserved)", None },												// 0x19
	{ "(Reserved)", None },												// 0x1A
	{ "(Reserved)", None },												// 0x1B
	{ "(Reserved)", None },												// 0x1C
	{ "(Reserved)", None },												// 0x1D
	{ "(Reserved)", None },												// 0x1E
	{ "(Reserved)", None },												// 0x1F
	{ "Display Attributes Report", LogicalCollection },					// 0x20
	{ "ASCII Character Set", StaticFlag },								// 0x21
	{ "Data Read Back", StaticFlag },									// 0x22
	{ "Font Read Back", StaticFlag },									// 0x23
	{ "Display Control Report", LogicalCollection },					// 0x24
	{ "Clear Display", DynamicFlag },									// 0x25
	{ "Display Enable", DynamicFlag },									// 0x26
	{ "Screen Saver Delay", DynamicFlag },								// 0x27
	{ "Screen Saver Enable", DynamicFlag },								// 0x28
	{ "Vertical Scroll", DynamicFlag },									// 0x29
	{ "Horizontal Scroll", DynamicFlag },								// 0x2A
	{ "Character Report", LogicalCollection },							// 0x2B
	{ "Display Data", DynamicValue },									// 0x2C
	{ "Display Status", LogicalCollection },							// 0x2D
	{ "Stat Not Ready", Selector },										// 0x2E
	{ "Stat Ready", Selector },											// 0x2F
	{ "Err Not A Loadable Character", Selector },						// 0x30
	{ "Err Font Data Cannot Be Read", Selector },						// 0x31
	{ "Cursor Position Report", LogicalCollection },					// 0x32
	{ "Row", DynamicValue },											// 0x33
	{ "Column", DynamicValue },											// 0x34
	{ "Rows", StaticValue },											// 0x35
	{ "Columns", StaticValue },											// 0x36
	{ "Cursor Pixel Positioning", StaticFlag },							// 0x37
	{ "Cursor Mode", DynamicFlag },										// 0x38
	{ "Cursor Enable", DynamicFlag },									// 0x39
	{ "Cursor Blink", DynamicFlag },									// 0x3A
	{ "Font Report", LogicalCollection },								// 0x3B
	{ "Font Data", BufferedByte },										// 0x3C
	{ "Character Width", StaticValue },									// 0x3D
	{ "Character Height", StaticValue },								// 0x3E
	{ "Character Spacing Horizontal", StaticValue },					// 0x3F
	{ "Character Spacing Vertical", StaticValue },						// 0x40
	{ "Unicode Character Set", StaticFlag },							// 0x41
	{ "Font 7-Segment", StaticFlag },									// 0x42
	{ "7-Segment Direct Map", StaticFlag },								// 0x43
	{ "Font 14-Segment", StaticFlag },									// 0x44
	{ "14-Segment Direct Map", StaticFlag },							// 0x45
	{ "Display Brightness", DynamicValue },								// 0x46
	{ "Display Contrast", DynamicValue },								// 0x47
	{ "Character Attribute", LogicalCollection },						// 0x48
	{ "Attribute Readback", StaticFlag },								// 0x49
	{ "Attribute Data", DynamicValue },									// 0x4A
	{ "Char Attr Enchance", OnOffControl },								// 0x4B
	{ "Char Attr Underline", OnOffControl },							// 0x4C
	{ "Char Attr Blink", OnOffControl },								// 0x4D
	{ "(Reserved)", None },												// 0x4E
	{ "(Reserved)", None },												// 0x4F
	{ "(Reserved)", None },												// 0x50
	{ "(Reserved)", None },												// 0x51
	{ "(Reserved)", None },												// 0x52
	{ "(Reserved)", None },												// 0x53
	{ "(Reserved)", None },												// 0x54
	{ "(Reserved)", None },												// 0x55
	{ "(Reserved)", None },												// 0x56
	{ "(Reserved)", None },												// 0x57
	{ "(Reserved)", None },												// 0x58
	{ "(Reserved)", None },												// 0x59
	{ "(Reserved)", None },												// 0x5A
	{ "(Reserved)", None },												// 0x5B
	{ "(Reserved)", None },												// 0x5C
	{ "(Reserved)", None },												// 0x5D
	{ "(Reserved)", None },												// 0x5E
	{ "(Reserved)", None },												// 0x5F
	{ "(Reserved)", None },												// 0x60
	{ "(Reserved)", None },												// 0x61
	{ "(Reserved)", None },												// 0x62
	{ "(Reserved)", None },												// 0x63
	{ "(Reserved)", None },												// 0x64
	{ "(Reserved)", None },												// 0x65
	{ "(Reserved)", None },												// 0x66
	{ "(Reserved)", None },												// 0x67
	{ "(Reserved)", None },												// 0x68
	{ "(Reserved)", None },												// 0x69
	{ "(Reserved)", None },												// 0x6A
	{ "(Reserved)", None },												// 0x6B
	{ "(Reserved)", None },												// 0x6C
	{ "(Reserved)", None },												// 0x6D
	{ "(Reserved)", None },												// 0x6E
	{ "(Reserved)", None },												// 0x6F
	{ "(Reserved)", None },												// 0x70
	{ "(Reserved)", None },												// 0x71
	{ "(Reserved)", None },												// 0x72
	{ "(Reserved)", None },												// 0x73
	{ "(Reserved)", None },												// 0x74
	{ "(Reserved)", None },												// 0x75
	{ "(Reserved)", None },												// 0x76
	{ "(Reserved)", None },												// 0x77
	{ "(Reserved)", None },												// 0x78
	{ "(Reserved)", None },												// 0x79
	{ "(Reserved)", None },												// 0x7A
	{ "(Reserved)", None },												// 0x7B
	{ "(Reserved)", None },												// 0x7C
	{ "(Reserved)", None },												// 0x7D
	{ "(Reserved)", None },												// 0x7E
	{ "(Reserved)", None },												// 0x7F
	{ "Bitmap Size X", StaticValue },									// 0x80
	{ "Bitmap Size Y", StaticValue },									// 0x81
	{ "(Reserved)", None },												// 0x82
	{ "Bit Depth Format", StaticValue },								// 0x83
	{ "Display Orientation", DynamicValue },							// 0x84
	{ "Palette Report", LogicalCollection },							// 0x85
	{ "Palette Data Size", StaticValue },								// 0x86
	{ "Palette Data Offset", StaticValue },								// 0x87
	{ "Palette Data", BufferedByte },									// 0x88
	{ "(Reserved)", None },												// 0x89
	{ "Blit Report", LogicalCollection },								// 0x8A
	{ "Blit Rectangle X1", StaticValue },								// 0x8B
	{ "Blit Rectangle Y1", StaticValue },								// 0x8C
	{ "Blit Rectangle X2", StaticValue },								// 0x8D
	{ "Blit Rectangle Y2", StaticValue },								// 0x8E
	{ "Blit Data", BufferedByte },										// 0x8F
	{ "Soft Button", LogicalCollection },								// 0x90
	{ "Soft Button ID", StaticValue },									// 0x91
	{ "Soft Button Side", StaticValue },								// 0x92
	{ "Soft Button Offset 1", StaticValue },							// 0x93
	{ "Soft Button Offset 2", StaticValue },							// 0x94
	{ "Soft Button Report", StaticValue },								// 0x95
};

// Usage Page 0x40 - Medical Instrument Page
static const usageInfo usagePage40[] = {
	{ "(Undefined)", None },											// 0x00
	{ "Medical Ultrasound", ApplicationCollection },					// 0x01
	{ "(Reserved)", None },												// 0x02
	{ "(Reserved)", None },												// 0x03
	{ "(Reserved)", None },												// 0x04
	{ "(Reserved)", None },												// 0x05
	{ "(Reserved)", None },												// 0x06
	{ "(Reserved)", None },												// 0x07
	{ "(Reserved)", None },												// 0x08
	{ "(Reserved)", None },												// 0x09
	{ "(Reserved)", None },												// 0x0A
	{ "(Reserved)", None },												// 0x0B
	{ "(Reserved)", None },												// 0x0C
	{ "(Reserved)", None },												// 0x0D
	{ "(Reserved)", None },												// 0x0E
	{ "(Reserved)", None },												// 0x0F
	{ "(Reserved)", None },												// 0x10
	{ "(Reserved)", None },												// 0x11
	{ "(Reserved)", None },												// 0x12
	{ "(Reserved)", None },												// 0x13
	{ "(Reserved)", None },												// 0x14
	{ "(Reserved)", None },												// 0x15
	{ "(Reserved)", None },												// 0x16
	{ "(Reserved)", None },												// 0x17
	{ "(Reserved)", None },												// 0x18
	{ "(Reserved)", None },												// 0x19
	{ "(Reserved)", None },												// 0x1A
	{ "(Reserved)", None },												// 0x1B
	{ "(Reserved)", None },												// 0x1C
	{ "(Reserved)", None },												// 0x1D
	{ "(Reserved)", None },												// 0x1E
	{ "(Reserved)", None },												// 0x1F
	{ "VCR/Acquisition", OnOffControl },								// 0x20
	{ "Freeze/Thaw", OnOffControl },									// 0x21
	{ "Clip Store", OneShotControl },									// 0x22
	{ "Update", OneShotControl },										// 0x23
	{ "Next", OneShotControl },											// 0x24
	{ "Save", OneShotControl },											// 0x25
	{ "Print", OneShotControl },										// 0x26
	{ "Microphone Enable", OneShotControl },							// 0x27
	{ "(Reserved)", None },												// 0x28
	{ "(Reserved)", None },												// 0x29
	{ "(Reserved)", None },												// 0x2A
	{ "(Reserved)", None },												// 0x2B
	{ "(Reserved)", None },												// 0x2C
	{ "(Reserved)", None },												// 0x2D
	{ "(Reserved)", None },												// 0x2E
	{ "(Reserved)", None },												// 0x2F
	{ "(Reserved)", None },												// 0x30
	{ "(Reserved)", None },												// 0x31
	{ "(Reserved)", None },												// 0x32
	{ "(Reserved)", None },												// 0x33
	{ "(Reserved)", None },												// 0x34
	{ "(Reserved)", None },												// 0x35
	{ "(Reserved)", None },												// 0x36
	{ "(Reserved)", None },												// 0x37
	{ "(Reserved)", None },												// 0x38
	{ "(Reserved)", None },												// 0x39
	{ "(Reserved)", None },												// 0x3A
	{ "(Reserved)", None },												// 0x3B
	{ "(Reserved)", None },												// 0x3C
	{ "(Reserved)", None },												// 0x3D
	{ "(Reserved)", None },												// 0x3E
	{ "(Reserved)", None },												// 0x3F
	{ "Cine", LinearControl },											// 0x40
	{ "Transmit Power", LinearControl },								// 0x41
	{ "Volume", LinearControl },										// 0x42
	{ "Focus", LinearControl },											// 0x43
	{ "Depth", LinearControl },											// 0x44
	{ "(Reserved)", None },												// 0x45
	{ "(Reserved)", None },												// 0x46
	{ "(Reserved)", None },												// 0x47
	{ "(Reserved)", None },												// 0x48
	{ "(Reserved)", None },												// 0x49
	{ "(Reserved)", None },												// 0x4A
	{ "(Reserved)", None },												// 0x4B
	{ "(Reserved)", None },												// 0x4C
	{ "(Reserved)", None },												// 0x4D
	{ "(Reserved)", None },												// 0x4E
	{ "(Reserved)", None },												// 0x4F
	{ "(Reserved)", None },												// 0x50
	{ "(Reserved)", None },												// 0x51
	{ "(Reserved)", None },												// 0x52
	{ "(Reserved)", None },												// 0x53
	{ "(Reserved)", None },												// 0x54
	{ "(Reserved)", None },												// 0x55
	{ "(Reserved)", None },												// 0x56
	{ "(Reserved)", None },												// 0x57
	{ "(Reserved)", None },												// 0x58
	{ "(Reserved)", None },												// 0x59
	{ "(Reserved)", None },												// 0x5A
	{ "(Reserved)", None },												// 0x5B
	{ "(Reserved)", None },												// 0x5C
	{ "(Reserved)", None },												// 0x5D
	{ "(Reserved)", None },												// 0x5E
	{ "(Reserved)", None },												// 0x5F
	{ "Soft Step - Primary", LinearControl },							// 0x60
	{ "Soft Step - Secondary", LinearControl },							// 0x61
	{ "(Reserved)", None },												// 0x62
	{ "(Reserved)", None },												// 0x63
	{ "(Reserved)", None },												// 0x64
	{ "(Reserved)", None },												// 0x65
	{ "(Reserved)", None },												// 0x66
	{ "(Reserved)", None },												// 0x67
	{ "(Reserved)", None },												// 0x68
	{ "(Reserved)", None },												// 0x69
	{ "(Reserved)", None },												// 0x6A
	{ "(Reserved)", None },												// 0x6B
	{ "(Reserved)", None },												// 0x6C
	{ "(Reserved)", None },												// 0x6D
	{ "(Reserved)", None },												// 0x6E
	{ "(Reserved)", None },												// 0x6F
	{ "Depth Gain Compensation", LinearControl },						// 0x70
	{ "(Reserved)", None },												// 0x71
	{ "(Reserved)", None },												// 0x72
	{ "(Reserved)", None },												// 0x73
	{ "(Reserved)", None },												// 0x74
	{ "(Reserved)", None },												// 0x75
	{ "(Reserved)", None },												// 0x76
	{ "(Reserved)", None },												// 0x77
	{ "(Reserved)", None },												// 0x78
	{ "(Reserved)", None },												// 0x79
	{ "(Reserved)", None },												// 0x7A
	{ "(Reserved)", None },												// 0x7B
	{ "(Reserved)", None },												// 0x7C
	{ "(Reserved)", None },												// 0x7D
	{ "(Reserved)", None },												// 0x7E
	{ "(Reserved)", None },												// 0x7F
	{ "Zoom Select", OneShotControl },									// 0x80
	{ "Zoom Adjust", LinearControl },									// 0x81
	{ "Spectral Doppler Mode Select", OneShotControl },					// 0x82
	{ "Spectral Doppler Adjust", LinearControl },						// 0x83
	{ "Color Doppler Mode Select", OneShotControl },					// 0x84
	{ "Color Doppler Adjust", LinearControl },							// 0x85
	{ "Motion Mode Select", OneShotControl },							// 0x86
	{ "Motion Mode Adjust", LinearControl },							// 0x87
	{ "2-D Mode Select", OneShotControl },								// 0x88
	{ "3-D Mode Select", LinearControl },								// 0x89
	{ "(Reserved)", None },												// 0x8A
	{ "(Reserved)", None },												// 0x8B
	{ "(Reserved)", None },												// 0x8C
	{ "(Reserved)", None },												// 0x8D
	{ "(Reserved)", None },												// 0x8E
	{ "(Reserved)", None },												// 0x8F
	{ "(Reserved)", None },												// 0x90
	{ "(Reserved)", None },												// 0x91
	{ "(Reserved)", None },												// 0x92
	{ "(Reserved)", None },												// 0x93
	{ "(Reserved)", None },												// 0x94
	{ "(Reserved)", None },												// 0x95
	{ "(Reserved)", None },												// 0x96
	{ "(Reserved)", None },												// 0x97
	{ "(Reserved)", None },												// 0x98
	{ "(Reserved)", None },												// 0x99
	{ "(Reserved)", None },												// 0x9A
	{ "(Reserved)", None },												// 0x9B
	{ "(Reserved)", None },												// 0x9C
	{ "(Reserved)", None },												// 0x9D
	{ "(Reserved)", None },												// 0x9E
	{ "(Reserved)", None },												// 0x9F
	{ "Soft Control Select", OneShotControl },							// 0xA0
	{ "Soft Control Adjust", LinearControl },							// 0xA1
};
	